"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtMultimedia import *
import enum


class QMediaFormat(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qmediaformat.html

    **Detailed Description**

    QMediaFormat describes an encoding format for a multimedia file or stream.

    You can check whether a certain media format can be used for encoding or
    decoding using QMediaFormat.
    """

    class ResolveFlags(enum.Enum):
        NoFlags: QMediaFormat = ...
        RequiresVideo: QMediaFormat = ...

    class ConversionMode(enum.Enum):
        Encode: QMediaFormat = ...
        Decode: QMediaFormat = ...

    class VideoCodec(enum.Enum):
        Unspecified: QMediaFormat = ...
        MPEG1: QMediaFormat = ...
        MPEG2: QMediaFormat = ...
        MPEG4: QMediaFormat = ...
        H264: QMediaFormat = ...
        H265: QMediaFormat = ...
        VP8: QMediaFormat = ...
        VP9: QMediaFormat = ...
        AV1: QMediaFormat = ...
        Theora: QMediaFormat = ...
        WMV: QMediaFormat = ...
        MotionJPEG: QMediaFormat = ...

    class AudioCodec(enum.Enum):
        Unspecified: QMediaFormat = ...
        MP3: QMediaFormat = ...
        AAC: QMediaFormat = ...
        AC3: QMediaFormat = ...
        EAC3: QMediaFormat = ...
        FLAC: QMediaFormat = ...
        DolbyTrueHD: QMediaFormat = ...
        Opus: QMediaFormat = ...
        Vorbis: QMediaFormat = ...
        Wave: QMediaFormat = ...
        WMA: QMediaFormat = ...
        ALAC: QMediaFormat = ...

    class FileFormat(enum.Enum):
        UnspecifiedFormat: QMediaFormat = ...
        WMV: QMediaFormat = ...
        AVI: QMediaFormat = ...
        Matroska: QMediaFormat = ...
        MPEG4: QMediaFormat = ...
        Ogg: QMediaFormat = ...
        QuickTime: QMediaFormat = ...
        WebM: QMediaFormat = ...
        Mpeg4Audio: QMediaFormat = ...
        AAC: QMediaFormat = ...
        WMA: QMediaFormat = ...
        MP3: QMediaFormat = ...
        FLAC: QMediaFormat = ...
        Wave: QMediaFormat = ...

    @typing.overload
    def __init__(self, format: "QMediaFormat.FileFormat" = ...) -> None:
        """
        https://doc.qt.io/qt-6/qmediaformat.html#QMediaFormat

        **QMediaFormat::QMediaFormat(QMediaFormat::FileFormat format =
        UnspecifiedFormat)**

        Constructs a QMediaFormat object for **format**.
        """
        ...

    @typing.overload
    def __init__(self, other: "QMediaFormat") -> None:
        """
        https://doc.qt.io/qt-6/qmediaformat.html#QMediaFormat-1

        **QMediaFormat::QMediaFormat(const QMediaFormat & other )**

        Constructs a QMediaFormat object by copying from **other**.
        """
        ...

    def resolveForEncoding(self, flags: "QMediaFormat.ResolveFlags") -> None:
        """
        https://doc.qt.io/qt-6/qmediaformat.html#resolveForEncoding

        **void QMediaFormat::resolveForEncoding(QMediaFormat::ResolveFlags flags
        )**

        Resolves the format, based on **flags** , to a format that is supported
        by **QMediaRecorder** .

        This method tries to find the best possible match for unspecified
        settings. Settings that are not supported by the recorder will be
        modified to the closest match that is supported.

        When resolving, priority is given in the following order:

        1. File format
          2. Video codec
          3. Audio codec
        """
        ...

    @staticmethod
    def videoCodecDescription(c: "QMediaFormat.VideoCodec") -> str:
        """
        https://doc.qt.io/qt-6/qmediaformat.html#videoCodecDescription

        **[static invokable] QString
        QMediaFormat::videoCodecDescription(QMediaFormat::VideoCodec codec )**

        Returns a description for **codec**.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .
        """
        ...

    @staticmethod
    def audioCodecDescription(c: "QMediaFormat.AudioCodec") -> str:
        """
        https://doc.qt.io/qt-6/qmediaformat.html#audioCodecDescription

        **[static invokable] QString
        QMediaFormat::audioCodecDescription(QMediaFormat::AudioCodec codec )**

        Returns a description for **codec**.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .
        """
        ...

    @staticmethod
    def fileFormatDescription(c: "QMediaFormat.FileFormat") -> str:
        """
        https://doc.qt.io/qt-6/qmediaformat.html#fileFormatDescription

        **[static invokable] QString
        QMediaFormat::fileFormatDescription(QMediaFormat::FileFormat fileFormat
        )**

        Returns a description for **fileFormat**.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .
        """
        ...

    @staticmethod
    def videoCodecName(c: "QMediaFormat.VideoCodec") -> str:
        """
        https://doc.qt.io/qt-6/qmediaformat.html#videoCodecName

        **[static invokable] QString
        QMediaFormat::videoCodecName(QMediaFormat::VideoCodec codec )**

        Returns a string based name for **codec**.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .
        """
        ...

    @staticmethod
    def audioCodecName(c: "QMediaFormat.AudioCodec") -> str:
        """
        https://doc.qt.io/qt-6/qmediaformat.html#audioCodecName

        **[static invokable] QString
        QMediaFormat::audioCodecName(QMediaFormat::AudioCodec codec )**

        Returns a string based name for **codec**.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .
        """
        ...

    @staticmethod
    def fileFormatName(c: "QMediaFormat.FileFormat") -> str:
        """
        https://doc.qt.io/qt-6/qmediaformat.html#fileFormatName

        **[static invokable] QString
        QMediaFormat::fileFormatName(QMediaFormat::FileFormat fileFormat )**

        Returns a string based name for **fileFormat**.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .
        """
        ...

    def supportedAudioCodecs(
        self, m: "QMediaFormat.ConversionMode"
    ) -> typing.List["QMediaFormat.AudioCodec"]:
        """
        https://doc.qt.io/qt-6/qmediaformat.html#supportedAudioCodecs

        **[invokable] QList<QMediaFormat::AudioCodec>
        QMediaFormat::supportedAudioCodecs(QMediaFormat::ConversionMode m )**

        Returns a list of audio codecs for the chosen file format and video
        codec ( **m** ).

        To get all supported audio codecs, run this query on a default
        constructed **QMediaFormat** .

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .

        **See also** **QMediaFormat::ConversionMode** .
        """
        ...

    def supportedVideoCodecs(
        self, m: "QMediaFormat.ConversionMode"
    ) -> typing.List["QMediaFormat.VideoCodec"]:
        """
        https://doc.qt.io/qt-6/qmediaformat.html#supportedVideoCodecs

        **[invokable] QList<QMediaFormat::VideoCodec>
        QMediaFormat::supportedVideoCodecs(QMediaFormat::ConversionMode m )**

        Returns a list of video codecs for the chosen file format and audio
        codec ( **m** ).

        To get all supported video codecs, run this query on a default
        constructed MediaFormat.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .

        **See also** **QMediaFormat::ConversionMode** .
        """
        ...

    def supportedFileFormats(
        self, m: "QMediaFormat.ConversionMode"
    ) -> typing.List["QMediaFormat.FileFormat"]:
        """
        https://doc.qt.io/qt-6/qmediaformat.html#supportedFileFormats

        **[invokable] QList<QMediaFormat::FileFormat>
        QMediaFormat::supportedFileFormats(QMediaFormat::ConversionMode m )**

        Returns a list of file formats for the audio and video codec indicated
        by **m**.

        To get all supported file formats, run this query on a default
        constructed **QMediaFormat** .

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .

        **See also** **QMediaFormat::ConversionMode** .
        """
        ...

    def mimeType(self) -> QtCore.QMimeType:
        """
        https://doc.qt.io/qt-6/qmediaformat.html#mimeType

        **QMimeType QMediaFormat::mimeType() const**

        Returns the **MIME type**  for the file format used in this media
        format.
        """
        ...

    def isSupported(self, mode: "QMediaFormat.ConversionMode") -> bool:
        """
        https://doc.qt.io/qt-6/qmediaformat.html#isSupported

        **[invokable] bool
        QMediaFormat::isSupported(QMediaFormat::ConversionMode mode ) const**

        Returns `true` if Qt Multimedia can encode or decode this format,
        depending on **mode**.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .
        """
        ...

    def audioCodec(self) -> "QMediaFormat.AudioCodec":
        """
        https://doc.qt.io/qt-6/qmediaformat.html#audioCodec

        **QMediaFormat::AudioCodec QMediaFormat::audioCodec() const**

        Returns the audio codec used in this format.

        **Note:** Getter function for property audioCodec.

        **See also** **setAudioCodec** () and **QMediaFormat::AudioCodec** .
        """
        ...

    def setAudioCodec(self, codec: "QMediaFormat.AudioCodec") -> None:
        """
        https://doc.qt.io/qt-6/qmediaformat.html#setAudioCodec

        **void QMediaFormat::setAudioCodec(QMediaFormat::AudioCodec codec )**

        Sets the audio codec to **codec**.

        **Note:** Setter function for property **audioCodec** .

        **See also** **audioCodec** () and **QMediaFormat::AudioCodec** .
        """
        ...

    def videoCodec(self) -> "QMediaFormat.VideoCodec":
        """
        https://doc.qt.io/qt-6/qmediaformat.html#videoCodec

        **QMediaFormat::VideoCodec QMediaFormat::videoCodec() const**

        Returns the video codec used in this format.

        **Note:** Getter function for property videoCodec.

        **See also** **setVideoCodec** () and **QMediaFormat::VideoCodec** .
        """
        ...

    def setVideoCodec(self, codec: "QMediaFormat.VideoCodec") -> None:
        """
        https://doc.qt.io/qt-6/qmediaformat.html#setVideoCodec

        **void QMediaFormat::setVideoCodec(QMediaFormat::VideoCodec codec )**

        Sets the video codec to **codec**.

        **Note:** Setter function for property **videoCodec** .

        **See also** **videoCodec** () and **QMediaFormat::VideoCodec** .
        """
        ...

    def setFileFormat(self, f: "QMediaFormat.FileFormat") -> None:
        """
        https://doc.qt.io/qt-6/qmediaformat.html#fileFormat-prop

        **fileFormat : FileFormat**

        This property holds the file (container) format of the media.

        **Access functions:**

        QMediaFormat::FileFormat **fileFormat** () const
        void
        **setFileFormat** (QMediaFormat::FileFormat **f** )

        **See also** **QMediaFormat::FileFormat** .
        """
        ...

    def fileFormat(self) -> "QMediaFormat.FileFormat":
        """
        https://doc.qt.io/qt-6/qmediaformat.html#fileFormat-prop

        **fileFormat : FileFormat**

        This property holds the file (container) format of the media.

        **Access functions:**

        QMediaFormat::FileFormat **fileFormat** () const
        void
        **setFileFormat** (QMediaFormat::FileFormat **f** )

        **See also** **QMediaFormat::FileFormat** .
        """
        ...

    def swap(self, other: "QMediaFormat") -> None:
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
from PyQt6 import QtCore
from PyQt6.QtWidgets import *
import enum


class QStyleOptionHeaderV2(QStyleOptionHeader):
    """
    https://doc.qt.io/qt-6/qstyleoptionheaderv2.html

    **Detailed Description**
    """

    class StyleOptionVersion(enum.Enum):
        Version: QStyleOptionHeaderV2 = ...

    class StyleOptionType(enum.Enum):
        Type: QStyleOptionHeaderV2 = ...

    isSectionDragTarget: bool = ...
    textElideMode: QtCore = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qstyleoptionheaderv2.html#QStyleOptionHeaderV2

        **QStyleOptionHeaderV2::QStyleOptionHeaderV2()**

        Constructs a QStyleOptionHeaderV2, initializing the members variables to
        their default values.
        """
        ...

    @typing.overload
    def __init__(self, other: "QStyleOptionHeaderV2") -> None:
        """
        https://doc.qt.io/qt-6/qstyleoptionheaderv2.html#QStyleOptionHeaderV2

        **QStyleOptionHeaderV2::QStyleOptionHeaderV2()**

        Constructs a QStyleOptionHeaderV2, initializing the members variables to
        their default values.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtGui import *


class QPen(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qpen.html

    **Detailed Description**

    A pen has a **style** (), **width** (), **brush** (), **capStyle** () and
    **joinStyle** ().

    The pen style defines the line type. The brush is used to fill strokes
    generated with the pen. Use the **QBrush**  class to specify fill styles.
    The cap style determines the line end caps that can be drawn using
    **QPainter** , while the join style describes how joins between two lines
    are drawn. The pen width can be specified in both integer (**width** ()) and
    floating point (**widthF** ()) precision. A line width of zero indicates a
    cosmetic pen. This means that the pen width is always drawn one pixel wide,
    independent of the **transformation**  set on the painter.

    The various settings can easily be modified using the corresponding
    **setStyle** (), **setWidth** (), **setBrush** (), **setCapStyle** () and
    **setJoinStyle** () functions (note that the painter's pen must be reset
    when altering the pen's properties).

    For example:

    **QPainter**  painter(this);
        **QPen**  pen(Qt::green, 3,
    Qt::DashDotLine, Qt::RoundCap, Qt::RoundJoin);
        painter.setPen(pen);

    which is equivalent to

    **QPainter**  painter(this);
        **QPen**  pen;  // creates a default pen
    pen.setStyle(Qt::DashDotLine);
        pen.setWidth(3);
    pen.setBrush(Qt::green);
        pen.setCapStyle(Qt::RoundCap);
    pen.setJoinStyle(Qt::RoundJoin);

        painter.setPen(pen);

    The default pen is a solid black brush with 1 width, square cap style
    (**Qt::SquareCap** ), and bevel join style (**Qt::BevelJoin** ).

    In addition QPen provides the **color** () and **setColor** () convenience
    functions to extract and set the color of the pen's brush, respectively.
    Pens may also be compared and streamed.

    For more information about painting in general, see the **Paint System**
    documentation.

    **Pen Style**

    Qt provides several built-in styles represented by the **Qt::PenStyle**
    enum:

    ![](images/qpen-solid.png)![](images/qpen-dash.png)![](images/qpen-dot.png)
    **Qt::SolidLine** **Qt::DashLine** **Qt::DotLine**
    ![](images/qpen-
    dashdot.png)![](images/qpen-dashdotdot.png)![](images/qpen-custom.png)
    **Qt::DashDotLine** **Qt::DashDotDotLine** **Qt::CustomDashLine**

    Simply use the **setStyle** () function to convert the pen style to either
    of the built-in styles, except the **Qt::CustomDashLine**  style which we
    will come back to shortly. Setting the style to **Qt::NoPen**  tells the
    painter to not draw lines or outlines. The default pen style is
    **Qt::SolidLine** .

    Since Qt 4.1 it is also possible to specify a custom dash pattern using the
    **setDashPattern** () function which implicitly converts the style of the
    pen to **Qt::CustomDashLine** . The pattern argument, a **QList** , must be
    specified as an even number of **qreal**  entries where the entries 1, 3,
    5... are the dashes and 2, 4, 6... are the spaces. For example, the custom
    pattern shown above is created using the following code:

    **QPen**  pen;
        **QList** <**qreal** > dashes;
        **qreal**  space = 4;
    dashes << 1 << space << 3 << space << 9 << space
                   << 27 <<
    space << 9 << space;

        pen.setDashPattern(dashes);

    Note that the dash pattern is specified in units of the pens width, e.g. a
    dash of length 5 in width 10 is 50 pixels long.

    The currently set dash pattern can be retrieved using the **dashPattern** ()
    function. Use the **isSolid** () function to determine whether the pen has a
    solid fill, or not.

    **Cap Style**

    The cap style defines how the end points of lines are drawn using
    **QPainter** . The cap style only apply to wide lines, i.e. when the width
    is 1 or greater. The **Qt::PenCapStyle**  enum provides the following
    styles:

    ![](images/qpen-square.png)![](images/qpen-flat.png)![](images/qpen-
    roundcap.png)
    **Qt::SquareCap** **Qt::FlatCap** **Qt::RoundCap**

    The **Qt::SquareCap**  style is a square line end that covers the end point
    and extends beyond it by half the line width. The **Qt::FlatCap**  style is
    a square line end that does not cover the end point of the line. And the
    **Qt::RoundCap**  style is a rounded line end covering the end point.

    The default is **Qt::SquareCap** .

    Whether or not end points are drawn when the pen width is 0 or 1 depends on
    the cap style. Using **Qt::SquareCap**  or **Qt::RoundCap**  they are drawn,
    using **Qt::FlatCap**  they are not drawn.

    **Join Style**

    The join style defines how joins between two connected lines can be drawn
    using **QPainter** . The join style only apply to wide lines, i.e. when the
    width is 1 or greater. The **Qt::PenJoinStyle**  enum provides the following
    styles:

    ![](images/qpen-bevel.png)![](images/qpen-miter.png)![](images/qpen-
    roundjoin.png)
    **Qt::BevelJoin** **Qt::MiterJoin** **Qt::RoundJoin**

    The **Qt::BevelJoin**  style fills the triangular notch between the two
    lines. The **Qt::MiterJoin**  style extends the lines to meet at an angle.
    And the **Qt::RoundJoin**  style fills a circular arc between the two lines.

    The default is **Qt::BevelJoin** .

    ![](images/qpen-miterlimit.png)

    When the **Qt::MiterJoin**  style is applied, it is possible to use the
    **setMiterLimit** () function to specify how far the miter join can extend
    from the join point. The **miterLimit** () is used to reduce artifacts
    between line joins where the lines are close to parallel.

    The **miterLimit** () must be specified in units of the pens width, e.g. a
    miter limit of 5 in width 10 is 50 pixels long. The default miter limit is
    2, i.e. twice the pen width in pixels.

    ![](images/qpen-demo.png)****The Path Stroking Example** **

    The Path
    Stroking example shows Qt's built-in dash patterns and shows how custom
    patterns can be used to extend the range of available patterns.

    **See also** **QPainter** , **QBrush** , **Path Stroking Example** , and
    **Scribble Example** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qpen.html#QPen

        **QPen::QPen()**

        Constructs a default black solid line pen with 1 width.
        """
        ...

    @typing.overload
    def __init__(self, a0: QtCore.Qt.PenStyle) -> None:
        """
        https://doc.qt.io/qt-6/qpen.html#QPen-1

        **QPen::QPen(Qt::PenStyle style )**

        Constructs a black pen with 1 width and the given **style**.

        **See also** **setStyle** ().
        """
        ...

    @typing.overload
    def __init__(
        self,
        brush: typing.Union[QBrush, QColor, QtCore.Qt.GlobalColor, int, QGradient],
        width: float,
        style: QtCore.Qt.PenStyle = ...,
        cap: QtCore.Qt.PenCapStyle = ...,
        join: QtCore.Qt.PenJoinStyle = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qpen.html#QPen-2

        **QPen::QPen(const QColor & color )**

        Constructs a solid line pen with 1 width and the given **color**.

        **See also** **setBrush** () and **setColor** ().
        """
        ...

    @typing.overload
    def __init__(
        self, pen: typing.Union["QPen", QColor, QtCore.Qt.GlobalColor, int, QGradient]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qpen.html#QPen-3

        **QPen::QPen(const QBrush & brush , qreal width , Qt::PenStyle style =
        Qt::SolidLine, Qt::PenCapStyle cap = Qt::SquareCap, Qt::PenJoinStyle
        join = Qt::BevelJoin)**

        Constructs a pen with the specified **brush** , **width** , pen
        **style** , **cap** style and **join** style.

        **See also** **setBrush** (), **setWidth** (), **setStyle** (),
        **setCapStyle** (), and **setJoinStyle** ().
        """
        ...

    @typing.overload
    def __init__(self, variant: typing.Any) -> None:
        """
        https://doc.qt.io/qt-6/qpen.html#QPen-4

        **QPen::QPen(const QPen & pen )**

        Constructs a pen that is a copy of the given **pen**.
        """
        ...

    def swap(self, other: "QPen") -> None:
        """
        https://doc.qt.io/qt-6/qpen.html#swap

        **void QPen::swap(QPen & other )**

        Swaps pen **other** with this pen. This operation is very fast and never
        fails.
        """
        ...

    def setCosmetic(self, cosmetic: bool) -> None:
        """
        https://doc.qt.io/qt-6/qpen.html#setCosmetic

        **void QPen::setCosmetic(bool cosmetic )**

        Sets this pen to cosmetic or non-cosmetic, depending on the value of
        **cosmetic**.

        **See also** **isCosmetic** ().
        """
        ...

    def isCosmetic(self) -> bool:
        """
        https://doc.qt.io/qt-6/qpen.html#isCosmetic

        **bool QPen::isCosmetic() const**

        Returns `true` if the pen is cosmetic; otherwise returns `false`.

        Cosmetic pens are used to draw strokes that have a constant width
        regardless of any transformations applied to the **QPainter**  they are
        used with. Drawing a shape with a cosmetic pen ensures that its outline
        will have the same thickness at different scale factors.

        A zero width pen is cosmetic by default.

        **See also** **setCosmetic** () and **widthF** ().
        """
        ...

    def setDashOffset(self, doffset: float) -> None:
        """
        https://doc.qt.io/qt-6/qpen.html#setDashOffset

        **void QPen::setDashOffset(qreal offset )**

        Sets the dash offset (the starting point on the dash pattern) for this
        pen to the **offset** specified. The offset is measured in terms of the
        units used to specify the dash pattern.

        ![](images/qpen-dashpattern.png)For example, a pattern where each stroke
        is four units long, followed by a gap of two units, will begin with the
        stroke when drawn as a line.

        However, if the dash offset is set to 4.0,
        any line drawn will begin with the gap. Values of the offset up to 4.0
        will cause part of the stroke to be drawn first, and values of the
        offset between 4.0 and 6.0 will cause the line to begin with part of the
        gap.

        **Note:** This implicitly converts the style of the pen to
        **Qt::CustomDashLine** .

        **See also** **dashOffset** ().
        """
        ...

    def dashOffset(self) -> float:
        """
        https://doc.qt.io/qt-6/qpen.html#dashOffset

        **qreal QPen::dashOffset() const**

        Returns the dash offset for the pen.

        **See also** **setDashOffset** ().
        """
        ...

    def setMiterLimit(self, limit: float) -> None:
        """
        https://doc.qt.io/qt-6/qpen.html#setMiterLimit

        **void QPen::setMiterLimit(qreal limit )**

        Sets the miter limit of this pen to the given **limit**.

        ![](images/qpen-miterlimit.png)

        The miter limit describes how far a miter join can extend from the join
        point. This is used to reduce artifacts between line joins where the
        lines are close to parallel.

        This value does only have effect when the pen style is set to
        **Qt::MiterJoin** . The value is specified in units of the pen's width,
        e.g. a miter limit of 5 in width 10 is 50 pixels long. The default miter
        limit is 2, i.e. twice the pen width in pixels.

        **See also** **miterLimit** (), **setJoinStyle** (), and **Join Style**
        .
        """
        ...

    def miterLimit(self) -> float:
        """
        https://doc.qt.io/qt-6/qpen.html#miterLimit

        **qreal QPen::miterLimit() const**

        Returns the miter limit of the pen. The miter limit is only relevant
        when the join style is set to **Qt::MiterJoin** .

        **See also** **setMiterLimit** () and **Join Style** .
        """
        ...

    def setDashPattern(self, pattern: typing.Iterable[float]) -> None:
        """
        https://doc.qt.io/qt-6/qpen.html#setDashPattern

        **void QPen::setDashPattern(const QList<qreal> & pattern )**

        Sets the dash pattern for this pen to the given **pattern**. This
        implicitly converts the style of the pen to **Qt::CustomDashLine** .

        The pattern must be specified as an even number of positive entries
        where the entries 1, 3, 5... are the dashes and 2, 4, 6... are the
        spaces. For example:

        ![](images/qpen-custom.png)



            **QPen**  pen;
            **QList**
        <**qreal** > dashes;
            **qreal**  space = 4;
            dashes << 1 << space
        << 3 << space << 9 << space
                       << 27 << space << 9 << space;
        pen.setDashPattern(dashes);

        The dash pattern is specified in units of the pens width; e.g. a dash of
        length 5 in width 10 is 50 pixels long. Note that a pen with zero width
        is equivalent to a cosmetic pen with a width of 1 pixel.

        Each dash is also subject to cap styles so a dash of 1 with square cap
        set will extend 0.5 pixels out in each direction resulting in a total
        width of 2.

        Note that the default cap style is **Qt::SquareCap** , meaning that a
        square line end covers the end point and extends beyond it by half the
        line width.

        **See also** **setStyle** (), **dashPattern** (), **setCapStyle** (),
        and **setCosmetic** ().
        """
        ...

    def dashPattern(self) -> typing.List[float]:
        """
        https://doc.qt.io/qt-6/qpen.html#dashPattern

        **QList<qreal> QPen::dashPattern() const**

        Returns the dash pattern of this pen.

        **See also** **setDashPattern** (), **style** (), and **isSolid** ().
        """
        ...

    def setJoinStyle(self, pcs: QtCore.Qt.PenJoinStyle) -> None:
        """
        https://doc.qt.io/qt-6/qpen.html#setJoinStyle

        **void QPen::setJoinStyle(Qt::PenJoinStyle style )**

        Sets the pen's join style to the given **style**. The default value is
        **Qt::BevelJoin** .

        **See also** **joinStyle** () and **Join Style** .
        """
        ...

    def joinStyle(self) -> QtCore.Qt.PenJoinStyle:
        """
        https://doc.qt.io/qt-6/qpen.html#joinStyle

        **Qt::PenJoinStyle QPen::joinStyle() const**

        Returns the pen's join style.

        **See also** **setJoinStyle** () and **Join Style** .
        """
        ...

    def setCapStyle(self, pcs: QtCore.Qt.PenCapStyle) -> None:
        """
        https://doc.qt.io/qt-6/qpen.html#setCapStyle

        **void QPen::setCapStyle(Qt::PenCapStyle style )**

        Sets the pen's cap style to the given **style**. The default value is
        **Qt::SquareCap** .

        **See also** **capStyle** () and **Cap Style** .
        """
        ...

    def capStyle(self) -> QtCore.Qt.PenCapStyle:
        """
        https://doc.qt.io/qt-6/qpen.html#capStyle

        **Qt::PenCapStyle QPen::capStyle() const**

        Returns the pen's cap style.

        **See also** **setCapStyle** () and **Cap Style** .
        """
        ...

    def isSolid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qpen.html#isSolid

        **bool QPen::isSolid() const**

        Returns `true` if the pen has a solid fill, otherwise false.

        **See also** **style** () and **dashPattern** ().
        """
        ...

    def setBrush(
        self, brush: typing.Union[QBrush, QColor, QtCore.Qt.GlobalColor, int, QGradient]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qpen.html#setBrush

        **void QPen::setBrush(const QBrush & brush )**

        Sets the brush used to fill strokes generated with this pen to the given
        **brush**.

        **See also** **brush** () and **setColor** ().
        """
        ...

    def brush(self) -> QBrush:
        """
        https://doc.qt.io/qt-6/qpen.html#brush

        **QBrush QPen::brush() const**

        Returns the brush used to fill strokes generated with this pen.

        **See also** **setBrush** ().
        """
        ...

    def setColor(
        self, color: typing.Union[QColor, QtCore.Qt.GlobalColor, int, QGradient]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qpen.html#setColor

        **void QPen::setColor(const QColor & color )**

        Sets the color of this pen's brush to the given **color**.

        **See also** **setBrush** () and **color** ().
        """
        ...

    def color(self) -> QColor:
        """
        https://doc.qt.io/qt-6/qpen.html#color

        **QColor QPen::color() const**

        Returns the color of this pen's brush.

        **See also** **brush** () and **setColor** ().
        """
        ...

    def setWidth(self, width: int) -> None:
        """
        https://doc.qt.io/qt-6/qpen.html#setWidth

        **void QPen::setWidth(int width )**

        Sets the pen width to the given **width** in pixels with integer
        precision.

        A line width of zero indicates a cosmetic pen. This means that the pen
        width is always drawn one pixel wide, independent of the
        **transformation**  set on the painter.

        Setting a pen width with a negative value is not supported.

        **See also** **setWidthF** () and **width** ().
        """
        ...

    def width(self) -> int:
        """
        https://doc.qt.io/qt-6/qpen.html#width

        **int QPen::width() const**

        Returns the pen width with integer precision.

        **See also** **setWidth** () and **widthF** ().
        """
        ...

    def setWidthF(self, width: float) -> None:
        """
        https://doc.qt.io/qt-6/qpen.html#setWidthF

        **void QPen::setWidthF(qreal width )**

        Sets the pen width to the given **width** in pixels with floating point
        precision.

        A line width of zero indicates a cosmetic pen. This means that the pen
        width is always drawn one pixel wide, independent of the
        **transformation**  on the painter.

        Setting a pen width with a negative value is not supported.

        **See also** **setWidth** () and **widthF** ().
        """
        ...

    def widthF(self) -> float:
        """
        https://doc.qt.io/qt-6/qpen.html#widthF

        **qreal QPen::widthF() const**

        Returns the pen width with floating point precision.

        **See also** **setWidthF** () and **width** ().
        """
        ...

    def setStyle(self, a0: QtCore.Qt.PenStyle) -> None:
        """
        https://doc.qt.io/qt-6/qpen.html#setStyle

        **void QPen::setStyle(Qt::PenStyle style )**

        Sets the pen style to the given **style**.

        See the **Qt::PenStyle**  documentation for a list of the available
        styles. Since Qt 4.1 it is also possible to specify a custom dash
        pattern using the **setDashPattern** () function which implicitly
        converts the style of the pen to **Qt::CustomDashLine** .

        **Note:** This function resets the dash offset to zero.

        **See also** **style** () and **Pen Style** .
        """
        ...

    def style(self) -> QtCore.Qt.PenStyle:
        """
        https://doc.qt.io/qt-6/qpen.html#style

        **Qt::PenStyle QPen::style() const**

        Returns the pen style.

        **See also** **setStyle** () and **Pen Style** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtQuick import *


class QQuickTextureFactory(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qquicktexturefactory.html

    **Detailed Description**

    The purpose of the texture factory is to provide a placeholder for a image
    data that can be converted into an OpenGL texture.

    Creating a texture directly is not possible as there is rarely an OpenGL
    context available in the thread that is responsible for loading the image
    data.
    """

    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qquicktexturefactory.html#QQuickTextureFactory

        **QQuickTextureFactory::QQuickTextureFactory()**

        Constructs a texture factory. Since QQuickTextureFactory is abstract, it
        cannot be instantiated directly.
        """
        ...

    @staticmethod
    def textureFactoryForImage(image: QtGui.QImage) -> "QQuickTextureFactory":
        """
        https://doc.qt.io/qt-6/qquicktexturefactory.html#textureFactoryForImage

        **[static, since 5.6] QQuickTextureFactory
        *QQuickTextureFactory::textureFactoryForImage(const QImage & image )**

        Returns a **QQuickTextureFactory**  holding the given **image**.

        This is typically used as a helper in
        **QQuickImageResponse::textureFactory** .

        This function was introduced in Qt 5.6.
        """
        ...

    def image(self) -> QtGui.QImage:
        """
        https://doc.qt.io/qt-6/qquicktexturefactory.html#image

        **[virtual] QImage QQuickTextureFactory::image() const**

        Returns an image version of this texture.

        The lifespan of the returned image is unknown, so the implementation
        should return a self contained **QImage** , not make use of the
        **QImage** (uchar *, ...) constructor.

        This function is not commonly used and is expected to be slow.
        """
        ...

    def textureByteCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qquicktexturefactory.html#textureByteCount

        **[pure virtual] int QQuickTextureFactory::textureByteCount() const**

        Returns the number of bytes of memory the texture consumes.
        """
        ...

    def textureSize(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qquicktexturefactory.html#textureSize

        **[pure virtual] QSize QQuickTextureFactory::textureSize() const**

        Returns the size of the texture. This function will be called from
        arbitrary threads and should not rely on an OpenGL context bound.
        """
        ...

    def createTexture(self, window: "QQuickWindow") -> "QSGTexture":
        """
        https://doc.qt.io/qt-6/qquicktexturefactory.html#createTexture

        **[pure virtual] QSGTexture
        *QQuickTextureFactory::createTexture(QQuickWindow * window ) const**

        This function is called on the scene graph rendering thread to create a
        **QSGTexture**  instance from the factory. **window** provides the
        context which this texture is created in.

        QML will internally cache the returned texture as needed. Each call to
        this function should return a unique instance.

        The OpenGL context used for rendering is bound when this function is
        called.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
from PyQt6 import QtCore
from PyQt6.QtQuick import *
import enum


class QSGImageNode(QSGGeometryNode):
    """
    https://doc.qt.io/qt-6/qsgimagenode.html

    **Detailed Description**

    **Warning:** The image node class must have a texture before being added to
    the scene graph to be rendered.
    """

    class TextureCoordinatesTransformFlag(enum.Flag):
        NoTransform: QSGImageNode = ...
        MirrorHorizontally: QSGImageNode = ...
        MirrorVertically: QSGImageNode = ...

    def anisotropyLevel(self) -> "QSGTexture.AnisotropyLevel":
        """
        https://doc.qt.io/qt-6/qsgimagenode.html#anisotropyLevel

        **[pure virtual] QSGTexture::AnisotropyLevel
        QSGImageNode::anisotropyLevel() const**

        Returns this image node's anistropy level.

        **See also** **setAnisotropyLevel** ().
        """
        ...

    def setAnisotropyLevel(self, level: "QSGTexture.AnisotropyLevel") -> None:
        """
        https://doc.qt.io/qt-6/qsgimagenode.html#setAnisotropyLevel

        **[pure virtual] void
        QSGImageNode::setAnisotropyLevel(QSGTexture::AnisotropyLevel level )**

        Sets this image node's anistropy level to **level**.

        **See also** **anisotropyLevel** ().
        """
        ...

    @staticmethod
    def rebuildGeometry(
        g: QSGGeometry,
        texture: "QSGTexture",
        rect: QtCore.QRectF,
        sourceRect: QtCore.QRectF,
        texCoordMode: "QSGImageNode.TextureCoordinatesTransformFlag",
    ) -> None:
        """
        https://doc.qt.io/qt-6/qsgimagenode.html#rebuildGeometry

        **[static] void QSGImageNode::rebuildGeometry(QSGGeometry * g ,
        QSGTexture * texture , const QRectF & rect , QRectF sourceRect ,
        QSGImageNode::TextureCoordinatesTransformMode texCoordMode )**

        Updates the geometry **g** with the **texture** , the coordinates in
        **rect** , and the texture coordinates from **sourceRect**.

        **g** is assumed to be a triangle strip of four vertices of type
        **QSGGeometry::TexturedPoint2D** .

        **texCoordMode** is used for normalizing the **sourceRect**.
        """
        ...

    def ownsTexture(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsgimagenode.html#ownsTexture

        **[pure virtual] bool QSGImageNode::ownsTexture() const**

        Returns `true` if the node takes ownership of the texture; otherwise
        `false`.

        **See also** **setOwnsTexture** ().
        """
        ...

    def setOwnsTexture(self, owns: bool) -> None:
        """
        https://doc.qt.io/qt-6/qsgimagenode.html#setOwnsTexture

        **[pure virtual] void QSGImageNode::setOwnsTexture(bool owns )**

        Sets whether the node takes ownership of the texture to **owns**.

        By default, the node does not take ownership of the texture.

        **See also** **ownsTexture** ().
        """
        ...

    def textureCoordinatesTransform(
        self,
    ) -> "QSGImageNode.TextureCoordinatesTransformFlag":
        """
        https://doc.qt.io/qt-6/qsgimagenode.html#textureCoordinatesTransform

        **[pure virtual] QSGImageNode::TextureCoordinatesTransformMode
        QSGImageNode::textureCoordinatesTransform() const**

        Returns the mode used to generate texture coordinates for this node.

        **See also** **setTextureCoordinatesTransform** ().
        """
        ...

    def setTextureCoordinatesTransform(
        self, mode: "QSGImageNode.TextureCoordinatesTransformFlag"
    ) -> None:
        """
        https://doc.qt.io/qt-6/qsgimagenode.html#setTextureCoordinatesTransform

        **[pure virtual] void QSGImageNode::setTextureCoordinatesTransform(QSGIm
        ageNode::TextureCoordinatesTransformMode mode )**

        Sets the method used to generate texture coordinates to **mode**. This
        can be used to obtain correct orientation of the texture. This is
        commonly needed when using a third-party OpenGL library to render to
        texture as OpenGL has an inverted y-axis relative to Qt Quick.

        **See also** **textureCoordinatesTransform** ().
        """
        ...

    def mipmapFiltering(self) -> "QSGTexture.Filtering":
        """
        https://doc.qt.io/qt-6/qsgimagenode.html#mipmapFiltering

        **[pure virtual] QSGTexture::Filtering QSGImageNode::mipmapFiltering()
        const**

        Returns the mipmap filtering for this image node.

        **See also** **setMipmapFiltering** ().
        """
        ...

    def setMipmapFiltering(self, filtering: "QSGTexture.Filtering") -> None:
        """
        https://doc.qt.io/qt-6/qsgimagenode.html#setMipmapFiltering

        **[pure virtual] void
        QSGImageNode::setMipmapFiltering(QSGTexture::Filtering filtering )**

        Sets the mipmap filtering to be used for this image node to
        **filtering**.

        For smooth scaling between mip maps, use **QSGTexture::Linear** . For
        normal scaling, use **QSGTexture::Nearest** .

        **See also** **mipmapFiltering** ().
        """
        ...

    def filtering(self) -> "QSGTexture.Filtering":
        """
        https://doc.qt.io/qt-6/qsgimagenode.html#filtering

        **[pure virtual] QSGTexture::Filtering QSGImageNode::filtering() const**

        Returns the filtering for this image node.

        **See also** **setFiltering** ().
        """
        ...

    def setFiltering(self, filtering: "QSGTexture.Filtering") -> None:
        """
        https://doc.qt.io/qt-6/qsgimagenode.html#setFiltering

        **[pure virtual] void QSGImageNode::setFiltering(QSGTexture::Filtering
        filtering )**

        Sets the filtering to be used for this image node to **filtering**.

        For smooth scaling, use **QSGTexture::Linear** . For normal scaling, use
        **QSGTexture::Nearest** .

        **See also** **filtering** ().
        """
        ...

    def texture(self) -> "QSGTexture":
        """
        https://doc.qt.io/qt-6/qsgimagenode.html#texture

        **[pure virtual] QSGTexture *QSGImageNode::texture() const**

        Returns the texture for this image node.

        **See also** **setTexture** ().
        """
        ...

    def setTexture(self, texture: "QSGTexture") -> None:
        """
        https://doc.qt.io/qt-6/qsgimagenode.html#setTexture

        **[pure virtual] void QSGImageNode::setTexture(QSGTexture * texture )**

        Sets the texture of this image node to **texture**.

        Use **setOwnsTexture** () to set whether the node should take ownership
        of the texture. By default, the node does not take ownership.

        **Warning:** An image node must have a texture before being added to the
        scenegraph to be rendered.

        **See also** **texture** ().
        """
        ...

    def sourceRect(self) -> QtCore.QRectF:
        """
        https://doc.qt.io/qt-6/qsgimagenode.html#sourceRect

        **[pure virtual] QRectF QSGImageNode::sourceRect() const**

        Returns the source rect of this image node.

        **See also** **setSourceRect** ().
        """
        ...

    @typing.overload
    def setSourceRect(self, r: QtCore.QRectF) -> None:
        """
        https://doc.qt.io/qt-6/qsgimagenode.html#setSourceRect

        **[pure virtual] void QSGImageNode::setSourceRect(const QRectF & rect
        )**

        Sets the source rect of this image node to **rect**.

        **See also** **sourceRect** ().
        """
        ...

    @typing.overload
    def setSourceRect(self, x: float, y: float, w: float, h: float) -> None:
        """
        https://doc.qt.io/qt-6/qsgimagenode.html#setSourceRect-1

        **void QSGImageNode::setSourceRect(qreal x , qreal y , qreal w , qreal h
        )**

        This is an overloaded function.

        Sets the rectangle of this image node to show its texture from ( **x** ,
        **y** ) and have width **w** and height **h** relatively to the
        **QSGTexture::textureSize** .
        """
        ...

    def rect(self) -> QtCore.QRectF:
        """
        https://doc.qt.io/qt-6/qsgimagenode.html#rect

        **[pure virtual] QRectF QSGImageNode::rect() const**

        Returns the target rect of this image node.

        **See also** **setRect** ().
        """
        ...

    @typing.overload
    def setRect(self, rect: QtCore.QRectF) -> None:
        """
        https://doc.qt.io/qt-6/qsgimagenode.html#setRect

        **[pure virtual] void QSGImageNode::setRect(const QRectF & rect )**

        Sets the target rect of this image node to **rect**.

        **See also** **rect** ().
        """
        ...

    @typing.overload
    def setRect(self, x: float, y: float, w: float, h: float) -> None:
        """
        https://doc.qt.io/qt-6/qsgimagenode.html#setRect-1

        **void QSGImageNode::setRect(qreal x , qreal y , qreal w , qreal h )**

        This is an overloaded function.

        Sets the rectangle of this image node to begin at ( **x** , **y** ) and
        have width **w** and height **h**.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtCore


class QOpenGLTimeMonitor(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qopengltimemonitor.html

    **Detailed Description**

    The QOpenGLTimeMonitor class is a convenience wrapper around a collection of
    OpenGL timer query objects used to measure intervals of time on the GPU to
    the level of granularity required by your rendering application.

    The OpenGL timer queries objects are queried in sequence to record the GPU
    timestamps at positions of interest in your rendering code. Once the results
    for all issues timer queries become available, the results can be fetched
    and QOpenGLTimerMonitor will calculate the recorded time intervals for you.

    The typical use case of this class is to either profile your application's
    rendering algorithms or to adjust those algorithms in real-time for dynamic
    performance/quality balancing.

    Prior to using QOpenGLTimeMonitor in your rendering function you should set
    the required number of sample points that you wish to record by calling
    setSamples(). Note that measuring N sample points will produce N-1 time
    intervals. Once you have set the number of sample points, call the
    **create** () function with a valid current OpenGL context to create the
    necessary query timer objects. These steps are usually performed just once
    in an initialization function.

    Use the **recordSample** () function to delimit blocks of code containing
    OpenGL commands that you wish to time. You can check availability of the
    resulting time samples and time intervals with **isResultAvailable** (). The
    calculated time intervals and the raw timestamp samples can be retrieved
    with the blocking **waitForIntervals** () and **waitForSamples** ()
    functions respectively.

    After retrieving the results and before starting a new round of taking
    samples (for example, in the next frame) be sure to call the **reset** ()
    function which will clear the cached results and reset the timer index back
    to the first timer object.

    **See also** **QOpenGLTimerQuery** .
    """

    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qopengltimemonitor.html#QOpenGLTimeMonitor

        **QOpenGLTimeMonitor::QOpenGLTimeMonitor(QObject * parent = nullptr)**

        Creates a QOpenGLTimeMonitor instance with the given **parent**. You
        must call **create** () with a valid OpenGL context before using.

        **See also** **setSampleCount** () and **create** ().
        """
        ...

    def reset(self) -> None:
        """
        https://doc.qt.io/qt-6/qopengltimemonitor.html#reset

        **void QOpenGLTimeMonitor::reset()**

        Resets the time monitor ready for use in another frame of rendering.
        Call this once you have obtained the previous results and before calling
        **recordSample** () for the first time on the next frame.

        **See also** **recordSample** ().
        """
        ...

    def waitForIntervals(self) -> typing.List[int]:
        """
        https://doc.qt.io/qt-6/qopengltimemonitor.html#waitForIntervals

        **QList<GLuint64> QOpenGLTimeMonitor::waitForIntervals() const**

        Returns a **QList**  containing the time intervals delimited by the
        calls to **recordSample** (). The resulting vector will contain one
        fewer element as this represents the intervening intervals rather than
        the actual timestamp samples.

        This function will block until OpenGL indicates the results are
        available. It is recommended to check the availability of the result
        prior to calling this function with **isResultAvailable** ().

        **See also** **waitForSamples** () and **isResultAvailable** ().
        """
        ...

    def waitForSamples(self) -> typing.List[int]:
        """
        https://doc.qt.io/qt-6/qopengltimemonitor.html#waitForSamples

        **QList<GLuint64> QOpenGLTimeMonitor::waitForSamples() const**

        Returns a **QList**  containing the GPU timestamps taken with
        **recordSample** ().

        This function will block until OpenGL indicates the results are
        available. It is recommended to check the availability of the result
        prior to calling this function with **isResultAvailable** ().

        **Note:** This function only works on systems that have OpenGL >=3.3 or
        the ARB_timer_query extension. See **QOpenGLTimerQuery**  for more
        details.

        **See also** **waitForIntervals** () and **isResultAvailable** ().
        """
        ...

    def isResultAvailable(self) -> bool:
        """
        https://doc.qt.io/qt-6/qopengltimemonitor.html#isResultAvailable

        **bool QOpenGLTimeMonitor::isResultAvailable() const**

        Returns `true` if the OpenGL timer query results are available.

        **See also** **waitForSamples** () and **waitForIntervals** ().
        """
        ...

    def recordSample(self) -> int:
        """
        https://doc.qt.io/qt-6/qopengltimemonitor.html#recordSample

        **int QOpenGLTimeMonitor::recordSample()**

        Issues an OpenGL timer query at this point in the OpenGL command queue.
        Calling this function in a sequence in your application's rendering
        function, will build up details of the GPU time taken to execute the
        OpenGL commands between successive calls to this function.

        **See also** **setSampleCount** (), **isResultAvailable** (),
        **waitForSamples** (), and **waitForIntervals** ().
        """
        ...

    def objectIds(self) -> typing.List[int]:
        """
        https://doc.qt.io/qt-6/qopengltimemonitor.html#objectIds

        **QList<GLuint> QOpenGLTimeMonitor::objectIds() const**

        Returns a **QList**  containing the object Ids of the OpenGL timer query
        objects.
        """
        ...

    def isCreated(self) -> bool:
        """
        https://doc.qt.io/qt-6/qopengltimemonitor.html#isCreated

        **bool QOpenGLTimeMonitor::isCreated() const**

        Returns `true` if the underlying OpenGL query objects have been created.
        If this returns `true` and the associated OpenGL context is current,
        then you are able to record time samples with this object.
        """
        ...

    def destroy(self) -> None:
        """
        https://doc.qt.io/qt-6/qopengltimemonitor.html#destroy

        **void QOpenGLTimeMonitor::destroy()**

        Destroys any OpenGL timer query objects used within this instance.

        **See also** **create** ().
        """
        ...

    def create(self) -> bool:
        """
        https://doc.qt.io/qt-6/qopengltimemonitor.html#create

        **bool QOpenGLTimeMonitor::create()**

        Instantiate **sampleCount** () OpenGL timer query objects that will be
        used to track the amount of time taken to execute OpenGL commands
        between successive calls to **recordSample** ().

        Returns `true` if the OpenGL timer query objects could be created.

        **See also** **destroy** (), **setSampleCount** (), and **recordSample**
        ().
        """
        ...

    def sampleCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qopengltimemonitor.html#sampleCount

        **int QOpenGLTimeMonitor::sampleCount() const**

        Returns the number of sample points that have been requested with
        **setSampleCount** (). If create was successfully called following
        **setSampleCount** (), then the value returned will be the actual number
        of sample points that can be used.

        The default value for sample count is 2, leading to the measurement of a
        single interval.

        **See also** **setSampleCount** ().
        """
        ...

    def setSampleCount(self, sampleCount: int) -> None:
        """
        https://doc.qt.io/qt-6/qopengltimemonitor.html#setSampleCount

        **void QOpenGLTimeMonitor::setSampleCount(int sampleCount )**

        Sets the number of sample points to **sampleCount**. After setting the
        number of samples with this function, you must call **create** () to
        instantiate the underlying OpenGL timer query objects.

        The new **sampleCount** must be at least 2.

        **See also** **sampleCount** (), **create** (), and **recordSample** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtQml import *
import enum


class QJSManagedValue(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qjsmanagedvalue.html

    **Detailed Description**

    The QJSManagedValue class allows interaction with JavaScript values in most
    ways you can interact with them from JavaScript itself. You can get and set
    properties and prototypes, and you can access arrays. Additionally, you can
    transform the value into the Qt counterparts of JavaScript objects. For
    example, a Url object may be transformed into a **QUrl** .

    A QJSManagedValue is always bound to a particular **QJSEngine** . You cannot
    use it independently. This means that you cannot have a QJSManagedValue from
    one engine be a property or a proptotype of a QJSManagedValue from a
    different engine.

    In contrast to **QJSValue** , almost all values held by QJSManagedValue live
    on the JavaScript heap. There is no inline or unmanaged storage. Therefore,
    you can get the prototype of a primitive value, and you can get the `length`
    property of a string.

    Only default-constructed or moved-from QJSManagedValues do not hold a value
    on the JavaScript heap. They represent `undefined`, which doesn't have any
    properties or prototypes.

    Also in contrast to **QJSValue** , QJSManagedValue does not catch any
    JavaScript exceptions. If an operation on a QJSManagedValue causes an error,
    it will generally return an `undefined` value and **QJSEngine::hasError** ()
    will return `true` afterwards. You can then catch the exception using
    **QJSEngine::catchError** (), or pass it up the stack, at your own
    discretion.

    **Note:** As the reference to the value on the JavaScript heap has to be
    freed on destruction, you cannot move a QJSManagedValue to a different
    thread. The destruction would take place in the new thread, which would
    create a race condition with the garbage collector on the original thread.
    This also means that you cannot hold a QJSManagedValue beyond the lifespan
    of its engine.

    The recommended way of working with a QJSManagedValue is creating it on the
    stack, possibly by moving a **QJSValue**  and adding an engine, then
    performing the necessary operations on it, and finally moving it back into a
    **QJSValue**  for storage. Moving between QJSManagedValue and **QJSValue**
    is fast.
    """

    class Type(enum.Enum):
        Undefined: QJSManagedValue = ...
        Boolean: QJSManagedValue = ...
        Number: QJSManagedValue = ...
        String: QJSManagedValue = ...
        Object: QJSManagedValue = ...
        Symbol: QJSManagedValue = ...
        Function: QJSManagedValue = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qjsmanagedvalue.html#QJSManagedValue-1

        **QJSManagedValue::QJSManagedValue()**

        Creates a QJSManagedValue that represents the JavaScript `undefined`
        value. This is the only value not stored on the JavaScript heap. Calling
        **engine** () on a default-constructed QJSManagedValue will return
        nullptr.
        """
        ...

    @typing.overload
    def __init__(
        self,
        value: typing.Union["QJSValue", "QJSValue.SpecialValue", bool, int, float, str],
        engine: QJSEngine,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qjsmanagedvalue.html#QJSManagedValue-2

        **QJSManagedValue::QJSManagedValue(QJSValue value , QJSEngine * engine
        )**

        Creates a QJSManagedValue from **value** , using the heap of **engine**.
        If **value** is itself managed and the engine it belongs to is not
        **engine** , the result is an `undefined` value, and a warning is
        generated.
        """
        ...

    @typing.overload
    def __init__(self, value: "QJSPrimitiveValue", engine: QJSEngine) -> None:
        """
        https://doc.qt.io/qt-6/qjsmanagedvalue.html#QJSManagedValue-3

        **QJSManagedValue::QJSManagedValue(const QJSPrimitiveValue & value ,
        QJSEngine * engine )**

        Creates a QJSManagedValue from **value** using the heap of **engine**.
        """
        ...

    @typing.overload
    def __init__(self, string: str, engine: QJSEngine) -> None:
        """
        https://doc.qt.io/qt-6/qjsmanagedvalue.html#QJSManagedValue-4

        **QJSManagedValue::QJSManagedValue(const QVariant & variant , QJSEngine
        * engine )**

        Creates a QJSManagedValue from **variant** using the heap of **engine**.
        """
        ...

    @typing.overload
    def __init__(self, variant: typing.Any, engine: QJSEngine) -> None:
        """
        https://doc.qt.io/qt-6/qjsmanagedvalue.html#QJSManagedValue-5

        **QJSManagedValue::QJSManagedValue(const QString & string , QJSEngine *
        engine )**

        Creates a QJSManagedValue from **string** using the heap of **engine**.
        """
        ...

    def callAsConstructor(
        self,
        arguments: typing.Iterable[
            typing.Union["QJSValue", "QJSValue.SpecialValue", bool, int, float, str]
        ] = ...,
    ) -> "QJSValue":
        """
        https://doc.qt.io/qt-6/qjsmanagedvalue.html#callAsConstructor

        **QJSValue QJSManagedValue::callAsConstructor(const QJSValueList &
        arguments = {}) const**

        If this **QJSManagedValue**  represents a JavaScript FunctionObject,
        calls it as constructor with the given **arguments** , and returns the
        result. Otherwise returns a JavaScript `undefined` value.

        The **arguments** have to be either primitive values or belong to the
        same **QJSEngine**  as this **QJSManagedValue** . Otherwise the call is
        not carried out and a JavaScript `undefined` value is returned.
        """
        ...

    def callWithInstance(
        self,
        instance: typing.Union[
            "QJSValue", "QJSValue.SpecialValue", bool, int, float, str
        ],
        arguments: typing.Iterable[
            typing.Union["QJSValue", "QJSValue.SpecialValue", bool, int, float, str]
        ] = ...,
    ) -> "QJSValue":
        """
        https://doc.qt.io/qt-6/qjsmanagedvalue.html#callWithInstance

        **QJSValue QJSManagedValue::callWithInstance(const QJSValue & instance ,
        const QJSValueList & arguments = {}) const**

        If this **QJSManagedValue**  represents a JavaScript FunctionObject,
        calls it on **instance** with the given **arguments** , and returns the
        result. Otherwise returns a JavaScript `undefined` value.

        The **arguments** and the **instance** have to be either primitive
        values or belong to the same **QJSEngine**  as this **QJSManagedValue**
        . Otherwise the call is not carried out and a JavaScript `undefined`
        value is returned.
        """
        ...

    def call(
        self,
        arguments: typing.Iterable[
            typing.Union["QJSValue", "QJSValue.SpecialValue", bool, int, float, str]
        ] = ...,
    ) -> "QJSValue":
        """
        https://doc.qt.io/qt-6/qjsmanagedvalue.html#call

        **QJSValue QJSManagedValue::call(const QJSValueList & arguments = {})
        const**

        If this **QJSManagedValue**  represents a JavaScript FunctionObject,
        calls it with the given **arguments** , and returns the result.
        Otherwise returns a JavaScript `undefined` value.

        The **arguments** have to be either primitive values or belong to the
        same **QJSEngine**  as this **QJSManagedValue** . Otherwise the call is
        not carried out and a JavaScript `undefined` value is returned.
        """
        ...

    @typing.overload
    def deleteProperty(self, name: str) -> bool:
        """
        https://doc.qt.io/qt-6/qjsmanagedvalue.html#deleteProperty

        **bool QJSManagedValue::deleteProperty(const QString & name )**

        Deletes the property **name** from this **QJSManagedValue** . Returns
        `true` if the deletion succeeded, or `false` otherwise.
        """
        ...

    @typing.overload
    def deleteProperty(self, arrayIndex: int) -> bool:
        """
        https://doc.qt.io/qt-6/qjsmanagedvalue.html#deleteProperty-1

        **bool QJSManagedValue::deleteProperty(quint32 arrayIndex )**

        Deletes the value stored at **arrayIndex** from this **QJSManagedValue**
        . Returns `true` if the deletion succeeded, or `false` otherwise.
        """
        ...

    @typing.overload
    def setProperty(
        self,
        name: str,
        value: typing.Union["QJSValue", "QJSValue.SpecialValue", bool, int, float, str],
    ) -> None:
        """
        https://doc.qt.io/qt-6/qjsmanagedvalue.html#setProperty

        **void QJSManagedValue::setProperty(const QString & name , const
        QJSValue & value )**

        Sets the property **name** to **value** on this **QJSManagedValue** .
        This can only be done on JavaScript values of type `object`. Furhermore,
        **value** has to be either a primitive or belong to the same engine as
        this value.

        **See also** **property** ().
        """
        ...

    @typing.overload
    def setProperty(
        self,
        arrayIndex: int,
        value: typing.Union["QJSValue", "QJSValue.SpecialValue", bool, int, float, str],
    ) -> None:
        """
        https://doc.qt.io/qt-6/qjsmanagedvalue.html#setProperty-1

        **void QJSManagedValue::setProperty(quint32 arrayIndex , const QJSValue
        & value )**

        Stores the **value** at **arrayIndex** in this **QJSManagedValue** .
        This can only be done on JavaScript values of type `object`, and it's
        not recommended if the value is not an array. Furhermore, **value** has
        to be either a primitive or belong to the same engine as this value.
        """
        ...

    @typing.overload
    def property(self, name: str) -> "QJSValue":
        """
        https://doc.qt.io/qt-6/qjsmanagedvalue.html#property

        **QJSValue QJSManagedValue::property(const QString & name ) const**

        Returns the property **name** of this **QJSManagedValue** . The
        prototype chain is searched if the property is not found on the actual
        object.

        **See also** **setProperty** ().
        """
        ...

    @typing.overload
    def property(self, arrayIndex: int) -> "QJSValue":
        """
        https://doc.qt.io/qt-6/qjsmanagedvalue.html#property-1

        **QJSValue QJSManagedValue::property(quint32 arrayIndex ) const**

        Returns the property stored at **arrayIndex** of this
        **QJSManagedValue** . The prototype chain is searched if the property is
        not found on the actual object.
        """
        ...

    @typing.overload
    def hasOwnProperty(self, name: str) -> bool:
        """
        https://doc.qt.io/qt-6/qjsmanagedvalue.html#hasOwnProperty

        **bool QJSManagedValue::hasOwnProperty(const QString & name ) const**

        Returns `true` if this **QJSManagedValue**  has a property **name** ,
        otherwise returns `false`. The properties of the prototype chain are not
        considered.
        """
        ...

    @typing.overload
    def hasOwnProperty(self, arrayIndex: int) -> bool:
        """
        https://doc.qt.io/qt-6/qjsmanagedvalue.html#hasOwnProperty-1

        **bool QJSManagedValue::hasOwnProperty(quint32 arrayIndex ) const**

        Returns `true` if this **QJSManagedValue**  has an array index
        **arrayIndex** , otherwise returns `false`. The properties of the
        prototype chain are not considered.
        """
        ...

    @typing.overload
    def hasProperty(self, name: str) -> bool:
        """
        https://doc.qt.io/qt-6/qjsmanagedvalue.html#hasProperty

        **bool QJSManagedValue::hasProperty(const QString & name ) const**

        Returns `true` if this **QJSManagedValue**  has a property **name** ,
        otherwise returns `false`. The properties of the prototype chain are
        considered.
        """
        ...

    @typing.overload
    def hasProperty(self, arrayIndex: int) -> bool:
        """
        https://doc.qt.io/qt-6/qjsmanagedvalue.html#hasProperty-1

        **bool QJSManagedValue::hasProperty(quint32 arrayIndex ) const**

        Returns `true` if this **QJSManagedValue**  has an array index
        **arrayIndex** , otherwise returns `false`. The properties of the
        prototype chain are considered.
        """
        ...

    def toDateTime(self) -> QtCore.QDateTime:
        """
        https://doc.qt.io/qt-6/qjsmanagedvalue.html#toDateTime

        **QDateTime QJSManagedValue::toDateTime() const**

        If this **QJSManagedValue**  holds a JavaScript Date object, returns an
        equivalent **QDateTime** . Otherwise returns an invalid one.
        """
        ...

    def toQMetaObject(self) -> QtCore.QMetaObject:
        """
        https://doc.qt.io/qt-6/qjsmanagedvalue.html#toQMetaObject

        **const QMetaObject *QJSManagedValue::toQMetaObject() const**

        If this **QJSManagedValue**  holds a **QMetaObject**  pointer, returns
        it. Otherwise returns nullptr.
        """
        ...

    def toQObject(self) -> QtCore.QObject:
        """
        https://doc.qt.io/qt-6/qjsmanagedvalue.html#toQObject

        **QObject *QJSManagedValue::toQObject() const**

        If this **QJSManagedValue**  holds a **QObject**  pointer, returns it.
        Otherwise returns nullptr.
        """
        ...

    def toUrl(self) -> QtCore.QUrl:
        """
        https://doc.qt.io/qt-6/qjsmanagedvalue.html#toUrl

        **QUrl QJSManagedValue::toUrl() const**

        If this **QJSManagedValue**  holds a JavaScript Url object, returns an
        equivalent **QUrl** . Otherwise returns an invalid one.
        """
        ...

    def toRegularExpression(self) -> QtCore.QRegularExpression:
        """
        https://doc.qt.io/qt-6/qjsmanagedvalue.html#toRegularExpression

        **QRegularExpression QJSManagedValue::toRegularExpression() const**

        If this **QJSManagedValue**  holds a JavaScript regular expression
        object, returns an equivalent **QRegularExpression** . Otherwise returns
        an invalid one.
        """
        ...

    def toInteger(self) -> int:
        """
        https://doc.qt.io/qt-6/qjsmanagedvalue.html#toInteger

        **int QJSManagedValue::toInteger() const**

        Converts the manged value to an integer. This first converts the value
        to a number by the rules of **toNumber** (), and then clamps it into the
        integer range by the rules given for coercing the arguments to
        JavaScript bit shift operators into 32bit integers.

        Internally, the value may already be stored as an integer, in which case
        a fast path is taken.

        **Note:** Conversion of a managed value to a number can throw an
        exception. In particular, symbols cannot be coerced into numbers, or a
        custom valueOf() method may throw. In this case the result is 0 and the
        engine carries an error after the conversion.

        **Note:** The JavaScript rules for coercing numbers into 32bit integers
        are unintuitive.
        """
        ...

    def toVariant(self) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qjsmanagedvalue.html#toVariant

        **QVariant QJSManagedValue::toVariant() const**

        Copies this **QJSManagedValue**  into a new **QVariant** . This also
        creates a useful **QVariant**  if **QJSManagedValue::isVariant** ()
        returns false. **QVariant**  can hold all types supported by
        **QJSManagedValue** .
        """
        ...

    def toJSValue(self) -> "QJSValue":
        """
        https://doc.qt.io/qt-6/qjsmanagedvalue.html#toJSValue

        **QJSValue QJSManagedValue::toJSValue() const**

        Copies this **QJSManagedValue**  into a new **QJSValue** . This is less
        efficient than move-constructing a **QJSValue**  from a
        **QJSManagedValue** , but retains the **QJSManagedValue** .
        """
        ...

    def toPrimitive(self) -> "QJSPrimitiveValue":
        """
        https://doc.qt.io/qt-6/qjsmanagedvalue.html#toPrimitive

        **QJSPrimitiveValue QJSManagedValue::toPrimitive() const**

        Converts the manged value to a **QJSPrimitiveValue** . If the managed
        value holds a type supported by **QJSPrimitiveValue** , the value is
        copied. Otherwise the value is converted to a string, and the string is
        stored in **QJSPrimitiveValue** .

        **Note:** Conversion of a managed value to a string can throw an
        exception. In particular, symbols cannot be coerced into strings, or a
        custom **toString** () method may throw. In this case the result is the
        undefined value and the engine carries an error after the conversion.
        """
        ...

    def toBoolean(self) -> bool:
        """
        https://doc.qt.io/qt-6/qjsmanagedvalue.html#toBoolean

        **bool QJSManagedValue::toBoolean() const**

        Converts the manged value to a boolean. If the managed value holds a
        boolean, that one is returned. Otherwise a boolean coercion by
        JavaScript rules is performed.
        """
        ...

    def toNumber(self) -> float:
        """
        https://doc.qt.io/qt-6/qjsmanagedvalue.html#toNumber

        **double QJSManagedValue::toNumber() const**

        Converts the manged value to a number. If the managed value holds a
        number, that one is returned. Otherwise a number coercion by JavaScript
        rules is performed.

        **Note:** Conversion of a managed value to a number can throw an
        exception. In particular, symbols cannot be coerced into numbers, or a
        custom valueOf() method may throw. In this case the result is 0 and the
        engine carries an error after the conversion.
        """
        ...

    def toString(self) -> str:
        """
        https://doc.qt.io/qt-6/qjsmanagedvalue.html#toString

        **QString QJSManagedValue::toString() const**

        Converts the manged value to a string. If the managed value holds a
        string, that one is returned. Otherwise a string coercion by JavaScript
        rules is performed.

        **Note:** Conversion of a managed value to a string can throw an
        exception. In particular, symbols cannot be coerced into strings, or a
        custom toString() method may throw. In this case the result is an empty
        string and the engine carries an error after the conversion.
        """
        ...

    def isError(self) -> bool:
        """
        https://doc.qt.io/qt-6/qjsmanagedvalue.html#isError

        **bool QJSManagedValue::isError() const**

        Returns `true` if this value represents a JavaScript Error object, or
        `false` otherwise.
        """
        ...

    def isDate(self) -> bool:
        """
        https://doc.qt.io/qt-6/qjsmanagedvalue.html#isDate

        **bool QJSManagedValue::isDate() const**

        Returns `true` if this value represents a JavaScript Date object, or
        `false` otherwise.
        """
        ...

    def isQMetaObject(self) -> bool:
        """
        https://doc.qt.io/qt-6/qjsmanagedvalue.html#isQMetaObject

        **bool QJSManagedValue::isQMetaObject() const**

        Returns `true` if this value represents a **QMetaObject**  pointer
        managed on the JavaScript heap, or `false` otherwise.
        """
        ...

    def isQObject(self) -> bool:
        """
        https://doc.qt.io/qt-6/qjsmanagedvalue.html#isQObject

        **bool QJSManagedValue::isQObject() const**

        Returns `true` if this value represents a **QObject**  pointer managed
        on the JavaScript heap, or `false` otherwise.
        """
        ...

    def isVariant(self) -> bool:
        """
        https://doc.qt.io/qt-6/qjsmanagedvalue.html#isVariant

        **bool QJSManagedValue::isVariant() const**

        Returns `true` if this value represents a **QVariant**  managed on the
        JavaScript heap, or `false` otherwise.
        """
        ...

    def isUrl(self) -> bool:
        """
        https://doc.qt.io/qt-6/qjsmanagedvalue.html#isUrl

        **bool QJSManagedValue::isUrl() const**

        Returns `true` if this value represents a JavaScript Url object, or
        `false` otherwise.
        """
        ...

    def isArray(self) -> bool:
        """
        https://doc.qt.io/qt-6/qjsmanagedvalue.html#isArray

        **bool QJSManagedValue::isArray() const**

        Returns `true` if this value represents a JavaScript Array object, or
        `false` otherwise.
        """
        ...

    def isRegularExpression(self) -> bool:
        """
        https://doc.qt.io/qt-6/qjsmanagedvalue.html#isRegularExpression

        **bool QJSManagedValue::isRegularExpression() const**

        Returns `true` if this value represents a JavaScript regular expression
        object, or `false` otherwise.
        """
        ...

    def isNull(self) -> bool:
        """
        https://doc.qt.io/qt-6/qjsmanagedvalue.html#isNull

        **bool QJSManagedValue::isNull() const**

        Returns `true` if this **QJSManagedValue**  holds the JavaScript `null`
        value, or `false` otherwise.
        """
        ...

    def isInteger(self) -> bool:
        """
        https://doc.qt.io/qt-6/qjsmanagedvalue.html#isInteger

        **bool QJSManagedValue::isInteger() const**

        Returns `true` if this **QJSManagedValue**  holds an integer value, or
        `false` otherwise. The storage format of a number does not affect the
        result of any operations performed on it, but if an integer is stored,
        many operations are faster.
        """
        ...

    def isFunction(self) -> bool:
        """
        https://doc.qt.io/qt-6/qjsmanagedvalue.html#isFunction

        **bool QJSManagedValue::isFunction() const**

        Returns `true` if the type of this **QJSManagedValue**  is `function`,
        `false` otherwise.
        """
        ...

    def isSymbol(self) -> bool:
        """
        https://doc.qt.io/qt-6/qjsmanagedvalue.html#isSymbol

        **bool QJSManagedValue::isSymbol() const**

        Returns `true` if the type of this **QJSManagedValue**  is `symbol`, or
        `false` otherwise.
        """
        ...

    def isObject(self) -> bool:
        """
        https://doc.qt.io/qt-6/qjsmanagedvalue.html#isObject

        **bool QJSManagedValue::isObject() const**

        Returns `true` if the type of this **QJSManagedValue**  is `object`, or
        `false` otherwise.
        """
        ...

    def isString(self) -> bool:
        """
        https://doc.qt.io/qt-6/qjsmanagedvalue.html#isString

        **bool QJSManagedValue::isString() const**

        Returns `true` if the type of this **QJSManagedValue**  is `string`, or
        `false` otherwise.
        """
        ...

    def isNumber(self) -> bool:
        """
        https://doc.qt.io/qt-6/qjsmanagedvalue.html#isNumber

        **bool QJSManagedValue::isNumber() const**

        Returns `true` if the type of this **QJSManagedValue**  is `number`, or
        `false` otherwise.
        """
        ...

    def isBoolean(self) -> bool:
        """
        https://doc.qt.io/qt-6/qjsmanagedvalue.html#isBoolean

        **bool QJSManagedValue::isBoolean() const**

        Returns `true` if the type of this **QJSManagedValue**  is `boolean`, or
        `false` otherwise.
        """
        ...

    def isUndefined(self) -> bool:
        """
        https://doc.qt.io/qt-6/qjsmanagedvalue.html#isUndefined

        **bool QJSManagedValue::isUndefined() const**

        Returns `true` if the type of this **QJSManagedValue**  is `undefined`,
        or `false` otherwise.
        """
        ...

    def type(self) -> "QJSManagedValue.Type":
        """
        https://doc.qt.io/qt-6/qjsmanagedvalue.html#type

        **QJSManagedValue::Type QJSManagedValue::type() const**

        Returns the JavaScript type of this **QJSManagedValue** .
        """
        ...

    def setPrototype(self, prototype: "QJSManagedValue") -> None:
        """
        https://doc.qt.io/qt-6/qjsmanagedvalue.html#setPrototype

        **void QJSManagedValue::setPrototype(const QJSManagedValue & prototype
        )**

        Sets the prototype of this **QJSManagedValue**  to **prototype**. A
        precondition is that **prototype** belongs to the same **QJSEngine**  as
        this **QJSManagedValue**  and is an object (including null).
        Furthermore, this **QJSManagedValue**  has to be an object (excluding
        null), too, and you cannot create prototype cycles.

        **See also** **prototype** ().
        """
        ...

    def prototype(self) -> "QJSManagedValue":
        """
        https://doc.qt.io/qt-6/qjsmanagedvalue.html#prototype

        **QJSManagedValue QJSManagedValue::prototype() const**

        Returns the prototype for this **QJSManagedValue** . This works on any
        value. You can, for example retrieve the JavaScript `boolean` prototype
        from a `boolean` value.

        **See also** **setPrototype** ().
        """
        ...

    def engine(self) -> QJSEngine:
        """
        https://doc.qt.io/qt-6/qjsmanagedvalue.html#engine

        **QJSEngine *QJSManagedValue::engine() const**

        Returns the **QJSEngine**  this **QJSManagedValue**  belongs to. Mind
        that the engine is always valid, unless the **QJSManagedValue**  is
        default-constructed or moved from. In the latter case a nullptr is
        returned.
        """
        ...

    def strictlyEquals(self, other: "QJSManagedValue") -> bool:
        """
        https://doc.qt.io/qt-6/qjsmanagedvalue.html#strictlyEquals

        **bool QJSManagedValue::strictlyEquals(const QJSManagedValue & other )
        const**

        Invokes the JavaScript '===' operator on this **QJSManagedValue**  and
        **other** , and returns the result.

        **See also** **equals** .
        """
        ...

    def equals(self, other: "QJSManagedValue") -> bool:
        """
        https://doc.qt.io/qt-6/qjsmanagedvalue.html#equals

        **bool QJSManagedValue::equals(const QJSManagedValue & other ) const**

        Invokes the JavaScript '==' operator on this **QJSManagedValue**  and
        **other** , and returns the result.

        **See also** **strictlyEquals** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6 import QtCore
from PyQt6.QtGui import *


class QInputEvent(QtCore.QEvent):
    """
    https://doc.qt.io/qt-6/qinputevent.html

    **Detailed Description**
    """

    def clone(self) -> "QInputEvent":
        ...

    def deviceType(self) -> "QInputDevice.DeviceType":
        """
        https://doc.qt.io/qt-6/qinputevent.html#deviceType

        **QInputDevice::DeviceType QInputEvent::deviceType() const**

        Returns the type of device that generated the event.
        """
        ...

    def device(self) -> "QInputDevice":
        """
        https://doc.qt.io/qt-6/qinputevent.html#device

        **[since 6.0] const QInputDevice *QInputEvent::device() const**

        Returns the source device that generated the original event.

        In case of a synthesized event, for example a mouse event that was
        generated from a touch event, `device()` continues to return the
        touchscreen device, so that you can tell that it did not come from an
        actual mouse. Thus `mouseEvent.source()->type() !=
        QInputDevice::DeviceType::Mouse` is one possible replacement for the Qt
        5 expression `mouseEvent.source() == Qt::MouseEventSynthesizedByQt`.

        This function was introduced in Qt 6.0.

        **See also** **QPointerEvent::pointingDevice** ().
        """
        ...

    def timestamp(self) -> int:
        """
        https://doc.qt.io/qt-6/qinputevent.html#timestamp

        **quint64 QInputEvent::timestamp() const**

        Returns the window system's timestamp for this event. It will normally
        be in milliseconds since some arbitrary point in time, such as the time
        when the system was started.
        """
        ...

    def modifiers(self) -> QtCore.Qt.KeyboardModifier:
        """
        https://doc.qt.io/qt-6/qinputevent.html#modifiers

        **Qt::KeyboardModifiers QInputEvent::modifiers() const**

        Returns the keyboard modifier flags that existed immediately before the
        event occurred.

        **See also** **QGuiApplication::keyboardModifiers** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6.QtCore import *
import enum


class QProcess(QIODevice):
    """
    https://doc.qt.io/qt-6/qprocess.html

    **Detailed Description**

    **Running a Process**

    To start a process, pass the name and command line arguments of the program
    you want to run as arguments to **start** (). Arguments are supplied as
    individual strings in a **QStringList** .

    Alternatively, you can set the program to run with **setProgram** () and
    **setArguments** (), and then call **start** () or **open** ().

    For example, the following code snippet runs the analog clock example in the
    Fusion style on X11 platforms by passing strings containing "-style" and
    "fusion" as two items in the list of arguments:

    **QObject**  *parent;
            ...
            **QString**  program =
    "./path/to/Qt/examples/widgets/analogclock";
            **QStringList**
    arguments;
            arguments << "-style" << "fusion";
    **QProcess**  *myProcess = new **QProcess** (parent);
    myProcess->start(program, arguments);

    QProcess then enters the **Starting**  state, and when the program has
    started, QProcess enters the **Running**  state and emits **started** ().

    QProcess allows you to treat a process as a sequential I/O device. You can
    write to and read from the process just as you would access a network
    connection using **QTcpSocket** . You can then write to the process's
    standard input by calling **write** (), and read the standard output by
    calling **read** (), **readLine** (), and **getChar** (). Because it
    inherits **QIODevice** , QProcess can also be used as an input source for
    **QXmlReader** , or for generating data to be uploaded using
    **QNetworkAccessManager** .

    When the process exits, QProcess reenters the **NotRunning**  state (the
    initial state), and emits **finished** ().

    The **finished** () signal provides the exit code and exit status of the
    process as arguments, and you can also call **exitCode** () to obtain the
    exit code of the last process that finished, and **exitStatus** () to obtain
    its exit status. If an error occurs at any point in time, QProcess will emit
    the **errorOccurred** () signal. You can also call **error** () to find the
    type of error that occurred last, and **state** () to find the current
    process state.

    **Note:** QProcess is not supported on VxWorks, iOS, tvOS, or watchOS.

    **Communicating via Channels**

    Processes have two predefined output channels: The standard output channel
    (`stdout`) supplies regular console output, and the standard error channel
    (`stderr`) usually supplies the errors that are printed by the process.
    These channels represent two separate streams of data. You can toggle
    between them by calling **setReadChannel** (). QProcess emits **readyRead**
    () when data is available on the current read channel. It also emits
    **readyReadStandardOutput** () when new standard output data is available,
    and when new standard error data is available, **readyReadStandardError** ()
    is emitted. Instead of calling **read** (), **readLine** (), or **getChar**
    (), you can explicitly read all data from either of the two channels by
    calling **readAllStandardOutput** () or **readAllStandardError** ().

    The terminology for the channels can be misleading. Be aware that the
    process's output channels correspond to QProcess's **read** channels,
    whereas the process's input channels correspond to QProcess's **write**
    channels. This is because what we read using QProcess is the process's
    output, and what we write becomes the process's input.

    QProcess can merge the two output channels, so that standard output and
    standard error data from the running process both use the standard output
    channel. Call **setProcessChannelMode** () with **MergedChannels**  before
    starting the process to activate this feature. You also have the option of
    forwarding the output of the running process to the calling, main process,
    by passing **ForwardedChannels**  as the argument. It is also possible to
    forward only one of the output channels - typically one would use
    **ForwardedErrorChannel** , but **ForwardedOutputChannel**  also exists.
    Note that using channel forwarding is typically a bad idea in GUI
    applications - you should present errors graphically instead.

    Certain processes need special environment settings in order to operate. You
    can set environment variables for your process by calling
    **setProcessEnvironment** (). To set a working directory, call
    **setWorkingDirectory** (). By default, processes are run in the current
    working directory of the calling process.

    The positioning and the screen Z-order of windows belonging to GUI
    applications started with QProcess are controlled by the underlying
    windowing system. For Qt 5 applications, the positioning can be specified
    using the `-qwindowgeometry` command line option; X11 applications generally
    accept a `-geometry` command line option.

    **Note:** On QNX, setting the working directory may cause all application
    threads, with the exception of the QProcess caller thread, to temporarily
    freeze during the spawning process, owing to a limitation in the operating
    system.

    **Synchronous Process API**

    QProcess provides a set of functions which allow it to be used without an
    event loop, by suspending the calling thread until certain signals are
    emitted:

    * **waitForStarted** () blocks until the process has started.
      *
    **waitForReadyRead** () blocks until new data is available for reading on
    the current read channel.
      * **waitForBytesWritten** () blocks until one
    payload of data has been written to the process.
      * **waitForFinished** ()
    blocks until the process has finished.

    Calling these functions from the main thread (the thread that calls
    **QApplication::exec** ()) may cause your user interface to freeze.

    The following example runs `gzip` to compress the string "Qt rocks!",
    without an event loop:

    **QProcess**  gzip;
            gzip.start("gzip", **QStringList** () << "-c");
    if (!gzip.waitForStarted())
                return false;
    gzip.write("Qt rocks!");
            gzip.closeWriteChannel();

            if
    (!gzip.waitForFinished())
                return false;
    **QByteArray**  result = gzip.readAll();

    **Notes for Windows Users**

    Some Windows commands (for example, `dir`) are not provided by separate
    applications, but by the command interpreter itself. If you attempt to use
    QProcess to execute these commands directly, it won't work. One possible
    solution is to execute the command interpreter itself (`cmd.exe` on some
    Windows systems), and ask the interpreter to execute the desired command.

    **See also** **QBuffer** , **QFile** , and **QTcpSocket** .
    """

    class InputChannelMode(enum.Enum):
        ManagedInputChannel: QProcess = ...
        ForwardedInputChannel: QProcess = ...

    class ProcessChannelMode(enum.Enum):
        SeparateChannels: QProcess = ...
        MergedChannels: QProcess = ...
        ForwardedChannels: QProcess = ...
        ForwardedOutputChannel: QProcess = ...
        ForwardedErrorChannel: QProcess = ...

    class ProcessChannel(enum.Enum):
        StandardOutput: QProcess = ...
        StandardError: QProcess = ...

    class ProcessState(enum.Enum):
        NotRunning: QProcess = ...
        Starting: QProcess = ...
        Running: QProcess = ...

    class ProcessError(enum.Enum):
        FailedToStart: QProcess = ...
        Crashed: QProcess = ...
        Timedout: QProcess = ...
        ReadError: QProcess = ...
        WriteError: QProcess = ...
        UnknownError: QProcess = ...

    class ExitStatus(enum.Enum):
        NormalExit: QProcess = ...
        CrashExit: QProcess = ...

    def __init__(self, parent: typing.Optional[QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qprocess.html#QProcess

        **QProcess::QProcess(QObject * parent = nullptr)**

        Constructs a QProcess object with the given **parent**.
        """
        ...

    def processId(self) -> int:
        """
        https://doc.qt.io/qt-6/qprocess.html#processId

        **[since 5.3] qint64 QProcess::processId() const**

        Returns the native process identifier for the running process, if
        available. If no process is currently running, `0` is returned.

        This function was introduced in Qt 5.3.
        """
        ...

    @staticmethod
    def nullDevice() -> str:
        """
        https://doc.qt.io/qt-6/qprocess.html#nullDevice

        **[static, since 5.2] QString QProcess::nullDevice()**

        The null device of the operating system.

        The returned file path uses native directory separators.

        This function was introduced in Qt 5.2.

        **See also** **QProcess::setStandardInputFile** (),
        **QProcess::setStandardOutputFile** (), and
        **QProcess::setStandardErrorFile** ().
        """
        ...

    def setInputChannelMode(self, mode: "QProcess.InputChannelMode") -> None:
        """
        https://doc.qt.io/qt-6/qprocess.html#setInputChannelMode

        **[since 5.2] void
        QProcess::setInputChannelMode(QProcess::InputChannelMode mode )**

        Sets the channel mode of the **QProcess**  standard input channel to the
        **mode** specified. This mode will be used the next time **start** () is
        called.

        This function was introduced in Qt 5.2.

        **See also** **inputChannelMode** () and **InputChannelMode** .
        """
        ...

    def inputChannelMode(self) -> "QProcess.InputChannelMode":
        """
        https://doc.qt.io/qt-6/qprocess.html#inputChannelMode

        **[since 5.2] QProcess::InputChannelMode QProcess::inputChannelMode()
        const**

        Returns the channel mode of the **QProcess**  standard input channel.

        This function was introduced in Qt 5.2.

        **See also** **setInputChannelMode** () and **InputChannelMode** .
        """
        ...

    def open(self, mode: QIODeviceBase.OpenModeFlag = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qprocess.html#open

        **[override virtual] bool QProcess::open(QIODeviceBase::OpenMode mode =
        ReadWrite)**

        Reimplements: **QIODevice::open** (QIODeviceBase::OpenMode mode).

        Starts the program set by **setProgram** () with arguments set by
        **setArguments** (). The OpenMode is set to **mode**.

        This method is an alias for **start** (), and exists only to fully
        implement the interface defined by **QIODevice** .

        Returns `true` if the program has been started.

        **See also** **start** (), **setProgram** (), and **setArguments** ().
        """
        ...

    def setArguments(self, arguments: typing.Iterable[str]) -> None:
        """
        https://doc.qt.io/qt-6/qprocess.html#setArguments

        **[since 5.1] void QProcess::setArguments(const QStringList & arguments
        )**

        Set the **arguments** to pass to the called program when starting the
        process. This function must be called before **start** ().

        This function was introduced in Qt 5.1.

        **See also** **start** (), **setProgram** (), and **arguments** ().
        """
        ...

    def arguments(self) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qprocess.html#arguments

        **[since 5.0] QStringList QProcess::arguments() const**

        Returns the command line arguments the process was last started with.

        This function was introduced in Qt 5.0.

        **See also** **setArguments** () and **start** ().
        """
        ...

    def setProgram(self, program: str) -> None:
        """
        https://doc.qt.io/qt-6/qprocess.html#setProgram

        **[since 5.1] void QProcess::setProgram(const QString & program )**

        Set the **program** to use when starting the process. This function must
        be called before **start** ().

        This function was introduced in Qt 5.1.

        **See also** **start** (), **setArguments** (), and **program** ().
        """
        ...

    def program(self) -> str:
        """
        https://doc.qt.io/qt-6/qprocess.html#program

        **[since 5.0] QString QProcess::program() const**

        Returns the program the process was last started with.

        This function was introduced in Qt 5.0.

        **See also** **setProgram** () and **start** ().
        """
        ...

    def processEnvironment(self) -> "QProcessEnvironment":
        """
        https://doc.qt.io/qt-6/qprocess.html#processEnvironment

        **QProcessEnvironment QProcess::processEnvironment() const**

        Returns the environment that **QProcess**  will pass to its child
        process, or an empty object if no environment has been set using
        setEnvironment() or **setProcessEnvironment** (). If no environment has
        been set, the environment of the calling process will be used.

        **See also** **setProcessEnvironment** (), **setEnvironment** (), and
        **QProcessEnvironment::isEmpty** ().
        """
        ...

    def setProcessEnvironment(self, environment: "QProcessEnvironment") -> None:
        """
        https://doc.qt.io/qt-6/qprocess.html#setProcessEnvironment

        **void QProcess::setProcessEnvironment(const QProcessEnvironment &
        environment )**

        Sets the **environment** that **QProcess**  will pass to the child
        process.

        For example, the following code adds the environment variable `TMPDIR`:

        **QProcess**  process;
            **QProcessEnvironment**  env =
        **QProcessEnvironment** ::systemEnvironment();
            env.insert("TMPDIR",
        "C:\\\\MyApp\\\\temp"); // Add an environment variable
        process.setProcessEnvironment(env);
            process.start("myapp");

        Note how, on Windows, environment variable names are case-insensitive.

        **See also** **processEnvironment** (),
        **QProcessEnvironment::systemEnvironment** (), and **setEnvironment**
        ().
        """
        ...

    def writeData(self, a0: PyQt6.sip.Buffer) -> int:
        """
        https://doc.qt.io/qt-6/qprocess.html#writeData

        **[override virtual protected] qint64 QProcess::writeData(const char *
        data , qint64 len )**

        Reimplements: **QIODevice::writeData** (const char *data, qint64
        maxSize).
        """
        ...

    def readData(self, maxlen: int) -> bytes:
        """
        https://doc.qt.io/qt-6/qprocess.html#readData

        **[override virtual protected] qint64 QProcess::readData(char * data ,
        qint64 maxlen )**

        Reimplements: **QIODevice::readData** (char *data, qint64 maxSize).
        """
        ...

    def setProcessState(self, state: "QProcess.ProcessState") -> None:
        """
        https://doc.qt.io/qt-6/qprocess.html#setProcessState

        **[protected] void QProcess::setProcessState(QProcess::ProcessState
        state )**

        Sets the current state of the **QProcess**  to the **state** specified.

        **See also** **state** ().
        """
        ...

    def kill(self) -> None:
        """
        https://doc.qt.io/qt-6/qprocess.html#kill

        **[slot] void QProcess::kill()**

        Kills the current process, causing it to exit immediately.

        On Windows, kill() uses TerminateProcess, and on Unix and macOS, the
        SIGKILL signal is sent to the process.

        **See also** **terminate** ().
        """
        ...

    def terminate(self) -> None:
        """
        https://doc.qt.io/qt-6/qprocess.html#terminate

        **[slot] void QProcess::terminate()**

        Attempts to terminate the process.

        The process may not exit as a result of calling this function (it is
        given the chance to prompt the user for any unsaved files, etc).

        On Windows, terminate() posts a WM_CLOSE message to all top-level
        windows of the process and then to the main thread of the process
        itself. On Unix and macOS the `SIGTERM` signal is sent.

        Console applications on Windows that do not run an event loop, or whose
        event loop does not handle the WM_CLOSE message, can only be terminated
        by calling **kill** ().

        **See also** **kill** ().
        """
        ...

    def setStandardOutputProcess(self, destination: "QProcess") -> None:
        """
        https://doc.qt.io/qt-6/qprocess.html#setStandardOutputProcess

        **void QProcess::setStandardOutputProcess(QProcess * destination )**

        Pipes the standard output stream of this process to the **destination**
        process' standard input.

        The following shell command:

        command1 | command2

        Can be accomplished with **QProcess**  with the following code:

        **QProcess**  process1;
            **QProcess**  process2;
        process1.setStandardOutputProcess(&process2);
        process1.start("command1");
            process2.start("command2");
        """
        ...

    def setStandardErrorFile(
        self, fileName: str, mode: QIODeviceBase.OpenModeFlag = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qprocess.html#setStandardErrorFile

        **void QProcess::setStandardErrorFile(const QString & fileName ,
        QIODeviceBase::OpenMode mode = Truncate)**

        Redirects the process' standard error to the file **fileName**. When the
        redirection is in place, the standard error read channel is closed:
        reading from it using **read** () will always fail, as will
        **readAllStandardError** (). The file will be appended to if **mode** is
        Append, otherwise, it will be truncated.

        See **setStandardOutputFile** () for more information on how the file is
        opened.

        Note: if **setProcessChannelMode** () was called with an argument of
        **QProcess::MergedChannels** , this function has no effect.

        **See also** **setStandardInputFile** (), **setStandardOutputFile** (),
        and **setStandardOutputProcess** ().
        """
        ...

    def setStandardOutputFile(
        self, fileName: str, mode: QIODeviceBase.OpenModeFlag = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qprocess.html#setStandardOutputFile

        **void QProcess::setStandardOutputFile(const QString & fileName ,
        QIODeviceBase::OpenMode mode = Truncate)**

        Redirects the process' standard output to the file **fileName**. When
        the redirection is in place, the standard output read channel is closed:
        reading from it using **read** () will always fail, as will
        **readAllStandardOutput** ().

        To discard all standard output from the process, pass **nullDevice** ()
        here. This is more efficient than simply never reading the standard
        output, as no **QProcess**  buffers are filled.

        If the file **fileName** doesn't exist at the moment **start** () is
        called, it will be created. If it cannot be created, the starting will
        fail.

        If the file exists and **mode** is QIODevice::Truncate, the file will be
        truncated. Otherwise (if **mode** is QIODevice::Append), the file will
        be appended to.

        Calling setStandardOutputFile() after the process has started has no
        effect.

        **See also** **setStandardInputFile** (), **setStandardErrorFile** (),
        and **setStandardOutputProcess** ().
        """
        ...

    def setStandardInputFile(self, fileName: str) -> None:
        """
        https://doc.qt.io/qt-6/qprocess.html#setStandardInputFile

        **void QProcess::setStandardInputFile(const QString & fileName )**

        Redirects the process' standard input to the file indicated by
        **fileName**. When an input redirection is in place, the **QProcess**
        object will be in read-only mode (calling **write** () will result in
        error).

        To make the process read EOF right away, pass **nullDevice** () here.
        This is cleaner than using **closeWriteChannel** () before writing any
        data, because it can be set up prior to starting the process.

        If the file **fileName** does not exist at the moment **start** () is
        called or is not readable, starting the process will fail.

        Calling setStandardInputFile() after the process has started has no
        effect.

        **See also** **setStandardOutputFile** (), **setStandardErrorFile** (),
        and **setStandardOutputProcess** ().
        """
        ...

    def setProcessChannelMode(self, mode: "QProcess.ProcessChannelMode") -> None:
        """
        https://doc.qt.io/qt-6/qprocess.html#setProcessChannelMode

        **void QProcess::setProcessChannelMode(QProcess::ProcessChannelMode mode
        )**

        Sets the channel mode of the **QProcess**  standard output and standard
        error channels to the **mode** specified. This mode will be used the
        next time **start** () is called. For example:

        **QProcess**  builder;
            builder.setProcessChannelMode(**QProcess**
        ::MergedChannels);
            builder.start("make", **QStringList** () <<
        "-j2");

            if (!builder.waitForFinished())
                **qDebug** ()
        << "Make failed:" << builder.errorString();
            else
                **qDebug**
        () << "Make output:" << builder.readAll();

        **See also** **processChannelMode** (), **ProcessChannelMode** , and
        **setReadChannel** ().
        """
        ...

    def processChannelMode(self) -> "QProcess.ProcessChannelMode":
        """
        https://doc.qt.io/qt-6/qprocess.html#processChannelMode

        **QProcess::ProcessChannelMode QProcess::processChannelMode() const**

        Returns the channel mode of the **QProcess**  standard output and
        standard error channels.

        **See also** **setProcessChannelMode** (), **ProcessChannelMode** , and
        **setReadChannel** ().
        """
        ...

    @staticmethod
    def systemEnvironment() -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qprocess.html#systemEnvironment

        **[static] QStringList QProcess::systemEnvironment()**

        Returns the environment of the calling process as a list of key=value
        pairs. Example:

        **QStringList**  environment = **QProcess** ::systemEnvironment();
        // environment = {"PATH=/usr/bin:/usr/local/bin",
            //
        "USER=greg", "HOME=/home/greg"}

        This function does not cache the system environment. Therefore, it's
        possible to obtain an updated version of the environment if low-level C
        library functions like `setenv` or `putenv` have been called.

        However, note that repeated calls to this function will recreate the
        list of environment variables, which is a non-trivial operation.

        **Note:** For new code, it is recommended to use
        **QProcessEnvironment::systemEnvironment** ()

        **See also** **QProcessEnvironment::systemEnvironment** () and
        **setProcessEnvironment** ().
        """
        ...

    @typing.overload
    @staticmethod
    def startDetached(
        program: str, arguments: typing.Iterable[str] = ..., workingDirectory: str = ...
    ) -> typing.Tuple[bool, int]:
        """
        https://doc.qt.io/qt-6/qprocess.html#startDetached

        **[since 5.10] bool QProcess::startDetached(qint64 * pid = nullptr)**

        Starts the program set by **setProgram** () with arguments set by
        **setArguments** () in a new process, and detaches from it. Returns
        `true` on success; otherwise returns `false`. If the calling process
        exits, the detached process will continue to run unaffected.

        **Unix:** The started process will run in its own session and act like a
        daemon.

        The process will be started in the directory set by
        **setWorkingDirectory** (). If **workingDirectory** () is empty, the
        working directory is inherited from the calling process.

        **Note:** On QNX, this may cause all application threads to temporarily
        freeze.

        If the function is successful then * **pid** is set to the process
        identifier of the started process; otherwise, it's set to -1. Note that
        the child process may exit and the PID may become invalid without
        notice. Furthermore, after the child process exits, the same PID may be
        recycled and used by a completely different process. User code should be
        careful when using this variable, especially if one intends to forcibly
        terminate the process by operating system means.

        Only the following property setters are supported by startDetached():

        * **setArguments** ()
          * **setCreateProcessArgumentsModifier** ()
          *
        **setNativeArguments** ()
          * **setProcessEnvironment** ()
          *
        **setProgram** ()
          * **setStandardErrorFile** ()
          *
        **setStandardInputFile** ()
          * **setStandardOutputFile** ()
          *
        **setProcessChannelMode** (**QProcess::MergedChannels** )
          *
        **setStandardOutputProcess** ()
          * **setWorkingDirectory** ()

        All other properties of the **QProcess**  object are ignored.

        **Note:** The called process inherits the console window of the calling
        process. To suppress console output, redirect standard/error output to
        **QProcess::nullDevice** ().

        This function was introduced in Qt 5.10.

        **See also** **start** () and **startDetached** (const QString &program,
        const QStringList &arguments, const QString &workingDirectory, qint64
        *pid).
        """
        ...

    @typing.overload
    def startDetached(self) -> typing.Tuple[bool, int]:
        """
        https://doc.qt.io/qt-6/qprocess.html#startDetached-1

        **[static] bool QProcess::startDetached(const QString & program , const
        QStringList & arguments = {}, const QString & workingDirectory =
        QString(), qint64 * pid = nullptr)**

        This function overloads startDetached().

        Starts the program **program** with the arguments **arguments** in a new
        process, and detaches from it. Returns `true` on success; otherwise
        returns `false`. If the calling process exits, the detached process will
        continue to run unaffected.

        Argument handling is identical to the respective **start** () overload.

        The process will be started in the directory **workingDirectory**. If
        **workingDirectory** is empty, the working directory is inherited from
        the calling process.

        If the function is successful then * **pid** is set to the process
        identifier of the started process.

        **See also** **start** ().
        """
        ...

    @staticmethod
    def execute(program: str, arguments: typing.Iterable[str] = ...) -> int:
        """
        https://doc.qt.io/qt-6/qprocess.html#execute

        **[static] int QProcess::execute(const QString & program , const
        QStringList & arguments = {})**

        Starts the program **program** with the arguments **arguments** in a new
        process, waits for it to finish, and then returns the exit code of the
        process. Any data the new process writes to the console is forwarded to
        the calling process.

        The environment and working directory are inherited from the calling
        process.

        Argument handling is identical to the respective **start** () overload.

        If the process cannot be started, -2 is returned. If the process
        crashes, -1 is returned. Otherwise, the process' exit code is returned.

        **See also** **start** ().
        """
        ...

    def close(self) -> None:
        """
        https://doc.qt.io/qt-6/qprocess.html#close

        **[override virtual] void QProcess::close()**

        Reimplements: **QIODevice::close** ().

        Closes all communication with the process and kills it. After calling
        this function, **QProcess**  will no longer emit **readyRead** (), and
        data can no longer be read or written.
        """
        ...

    def isSequential(self) -> bool:
        """
        https://doc.qt.io/qt-6/qprocess.html#isSequential

        **[override virtual] bool QProcess::isSequential() const**

        Reimplements: **QIODevice::isSequential() const** .
        """
        ...

    def bytesToWrite(self) -> int:
        """
        https://doc.qt.io/qt-6/qprocess.html#bytesToWrite

        **[override virtual] qint64 QProcess::bytesToWrite() const**

        Reimplements: **QIODevice::bytesToWrite() const** .
        """
        ...

    def exitStatus(self) -> "QProcess.ExitStatus":
        """
        https://doc.qt.io/qt-6/qprocess.html#exitStatus

        **QProcess::ExitStatus QProcess::exitStatus() const**

        Returns the exit status of the last process that finished.

        On Windows, if the process was terminated with TerminateProcess() from
        another application, this function will still return **NormalExit**
        unless the exit code is less than 0.
        """
        ...

    def exitCode(self) -> int:
        """
        https://doc.qt.io/qt-6/qprocess.html#exitCode

        **int QProcess::exitCode() const**

        Returns the exit code of the last process that finished.

        This value is not valid unless **exitStatus** () returns **NormalExit**
        .
        """
        ...

    def readAllStandardError(self) -> QByteArray:
        """
        https://doc.qt.io/qt-6/qprocess.html#readAllStandardError

        **QByteArray QProcess::readAllStandardError()**

        Regardless of the current read channel, this function returns all data
        available from the standard error of the process as a **QByteArray** .

        **See also** **readyReadStandardError** (), **readAllStandardOutput**
        (), **readChannel** (), and **setReadChannel** ().
        """
        ...

    def readAllStandardOutput(self) -> QByteArray:
        """
        https://doc.qt.io/qt-6/qprocess.html#readAllStandardOutput

        **QByteArray QProcess::readAllStandardOutput()**

        Regardless of the current read channel, this function returns all data
        available from the standard output of the process as a **QByteArray** .

        **See also** **readyReadStandardOutput** (), **readAllStandardError**
        (), **readChannel** (), and **setReadChannel** ().
        """
        ...

    def waitForFinished(self, msecs: int = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qprocess.html#waitForFinished

        **bool QProcess::waitForFinished(int msecs = 30000)**

        Blocks until the process has finished and the **finished** () signal has
        been emitted, or until **msecs** milliseconds have passed.

        Returns `true` if the process finished; otherwise returns `false` (if
        the operation timed out, if an error occurred, or if this **QProcess**
        is already finished).

        This function can operate without an event loop. It is useful when
        writing non-GUI applications and when performing I/O operations in a
        non-GUI thread.

        **Warning:** Calling this function from the main (GUI) thread might
        cause your user interface to freeze.

        If msecs is -1, this function will not time out.

        **See also** **finished** (), **waitForStarted** (),
        **waitForReadyRead** (), and **waitForBytesWritten** ().
        """
        ...

    def waitForBytesWritten(self, msecs: int = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qprocess.html#waitForBytesWritten

        **[override virtual] bool QProcess::waitForBytesWritten(int msecs =
        30000)**

        Reimplements: **QIODevice::waitForBytesWritten** (int msecs).
        """
        ...

    def waitForReadyRead(self, msecs: int = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qprocess.html#waitForReadyRead

        **[override virtual] bool QProcess::waitForReadyRead(int msecs =
        30000)**

        Reimplements: **QIODevice::waitForReadyRead** (int msecs).
        """
        ...

    def waitForStarted(self, msecs: int = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qprocess.html#waitForStarted

        **bool QProcess::waitForStarted(int msecs = 30000)**

        Blocks until the process has started and the **started** () signal has
        been emitted, or until **msecs** milliseconds have passed.

        Returns `true` if the process was started successfully; otherwise
        returns `false` (if the operation timed out or if an error occurred).

        This function can operate without an event loop. It is useful when
        writing non-GUI applications and when performing I/O operations in a
        non-GUI thread.

        **Warning:** Calling this function from the main (GUI) thread might
        cause your user interface to freeze.

        If msecs is -1, this function will not time out.

        **Note:** On some UNIX operating systems, this function may return true
        but the process may later report a **QProcess::FailedToStart**  error.

        **See also** **started** (), **waitForReadyRead** (),
        **waitForBytesWritten** (), and **waitForFinished** ().
        """
        ...

    def state(self) -> "QProcess.ProcessState":
        """
        https://doc.qt.io/qt-6/qprocess.html#state

        **QProcess::ProcessState QProcess::state() const**

        Returns the current state of the process.

        **See also** **stateChanged** () and **error** ().
        """
        ...

    def error(self) -> "QProcess.ProcessError":
        """
        https://doc.qt.io/qt-6/qprocess.html#error

        **QProcess::ProcessError QProcess::error() const**

        Returns the type of error that occurred last.

        **See also** **state** ().
        """
        ...

    def setWorkingDirectory(self, dir: str) -> None:
        """
        https://doc.qt.io/qt-6/qprocess.html#setWorkingDirectory

        **void QProcess::setWorkingDirectory(const QString & dir )**

        Sets the working directory to **dir**. **QProcess**  will start the
        process in this directory. The default behavior is to start the process
        in the working directory of the calling process.

        **Note:** On QNX, this may cause all application threads to temporarily
        freeze.

        **See also** **workingDirectory** () and **start** ().
        """
        ...

    def workingDirectory(self) -> str:
        """
        https://doc.qt.io/qt-6/qprocess.html#workingDirectory

        **QString QProcess::workingDirectory() const**

        If **QProcess**  has been assigned a working directory, this function
        returns the working directory that the **QProcess**  will enter before
        the program has started. Otherwise, (i.e., no directory has been
        assigned,) an empty string is returned, and **QProcess**  will use the
        application's current working directory instead.

        **See also** **setWorkingDirectory** ().
        """
        ...

    def closeWriteChannel(self) -> None:
        """
        https://doc.qt.io/qt-6/qprocess.html#closeWriteChannel

        **void QProcess::closeWriteChannel()**

        Schedules the write channel of **QProcess**  to be closed. The channel
        will close once all data has been written to the process. After calling
        this function, any attempts to write to the process will fail.

        Closing the write channel is necessary for programs that read input data
        until the channel has been closed. For example, the program "more" is
        used to display text data in a console on both Unix and Windows. But it
        will not display the text data until **QProcess** 's write channel has
        been closed. Example:

        **QProcess**  more;
            more.start("more");
            more.write("Text to
        display");
            more.closeWriteChannel();
            // QProcess will emit
        readyRead() once "more" starts printing

        The write channel is implicitly opened when **start** () is called.

        **See also** **closeReadChannel** ().
        """
        ...

    def closeReadChannel(self, channel: "QProcess.ProcessChannel") -> None:
        """
        https://doc.qt.io/qt-6/qprocess.html#closeReadChannel

        **void QProcess::closeReadChannel(QProcess::ProcessChannel channel )**

        Closes the read channel **channel**. After calling this function,
        **QProcess**  will no longer receive data on the channel. Any data that
        has already been received is still available for reading.

        Call this function to save memory, if you are not interested in the
        output of the process.

        **See also** **closeWriteChannel** () and **setReadChannel** ().
        """
        ...

    def setReadChannel(self, channel: "QProcess.ProcessChannel") -> None:
        """
        https://doc.qt.io/qt-6/qprocess.html#setReadChannel

        **void QProcess::setReadChannel(QProcess::ProcessChannel channel )**

        Sets the current read channel of the **QProcess**  to the given
        **channel**. The current input channel is used by the functions **read**
        (), **readAll** (), **readLine** (), and **getChar** (). It also
        determines which channel triggers **QProcess**  to emit **readyRead**
        ().

        **See also** **readChannel** ().
        """
        ...

    def readChannel(self) -> "QProcess.ProcessChannel":
        """
        https://doc.qt.io/qt-6/qprocess.html#readChannel

        **QProcess::ProcessChannel QProcess::readChannel() const**

        Returns the current read channel of the **QProcess** .

        **See also** **setReadChannel** ().
        """
        ...

    def startCommand(
        self, command: str, mode: QIODeviceBase.OpenModeFlag = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qprocess.html#startCommand

        **[since 6.0] void QProcess::startCommand(const QString & command ,
        QIODeviceBase::OpenMode mode = ReadWrite)**

        Starts the command **command** in a new process. The OpenMode is set to
        **mode**.

        **command** is a single string of text containing both the program name
        and its arguments. The arguments are separated by one or more spaces.
        For example:

        **QProcess**  process;
            process.startCommand("del /s *.txt");
            //
        same as process.start("del", QStringList() << "/s" << "*.txt");
            ...

        Arguments containing spaces must be quoted to be correctly supplied to
        the new process. For example:

        **QProcess**  process;
            process.startCommand("dir \\"My Documents\\"");

        Literal quotes in the **command** string are represented by triple
        quotes. For example:

        **QProcess**  process;
            process.startCommand("dir \\"Epic 12\\"\\"\\"
        Singles\\"");

        After the **command** string has been split and unquoted, this function
        behaves like **start** ().

        On operating systems where the system API for passing command line
        arguments to a subprocess natively uses a single string (Windows), one
        can conceive command lines which cannot be passed via **QProcess** 's
        portable list-based API. In these rare cases you need to use
        **setProgram** () and **setNativeArguments** () instead of this
        function.

        This function was introduced in Qt 6.0.

        **See also** **splitCommand** () and **start** ().
        """
        ...

    @typing.overload
    def start(
        self,
        program: str,
        arguments: typing.Iterable[str] = ...,
        mode: QIODeviceBase.OpenModeFlag = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qprocess.html#start

        **void QProcess::start(const QString & program , const QStringList &
        arguments = {}, QIODeviceBase::OpenMode mode = ReadWrite)**

        Starts the given **program** in a new process, passing the command line
        arguments in **arguments**.

        The **QProcess**  object will immediately enter the Starting state. If
        the process starts successfully, **QProcess**  will emit **started** ();
        otherwise, **errorOccurred** () will be emitted.

        **Note:** Processes are started asynchronously, which means the
        **started** () and **errorOccurred** () signals may be delayed. Call
        **waitForStarted** () to make sure the process has started (or has
        failed to start) and those signals have been emitted.

        **Note:** No further splitting of the arguments is performed.

        **Windows:** The arguments are quoted and joined into a command line
        that is compatible with the `CommandLineToArgvW()` Windows function. For
        programs that have different command line quoting requirements, you need
        to use **setNativeArguments** (). One notable program that does not
        follow the `CommandLineToArgvW()` rules is cmd.exe and, by consequence,
        all batch scripts.

        The OpenMode is set to **mode**.

        If the **QProcess**  object is already running a process, a warning may
        be printed at the console, and the existing process will continue
        running unaffected.

        **See also** **processId** (), **started** (), **waitForStarted** (),
        and **setNativeArguments** ().
        """
        ...

    @typing.overload
    def start(self, mode: QIODeviceBase.OpenModeFlag = ...) -> None:
        """
        https://doc.qt.io/qt-6/qprocess.html#start-1

        **[since 5.1] void QProcess::start(QIODeviceBase::OpenMode mode =
        ReadWrite)**

        This is an overloaded function.

        Starts the program set by **setProgram** () with arguments set by
        **setArguments** (). The OpenMode is set to **mode**.

        This function was introduced in Qt 5.1.

        **See also** **open** (), **setProgram** (), and **setArguments** ().
        """
        ...

    @property
    def errorOccurred(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qprocess.html#errorOccurred

        **[signal, since 5.6] void
        QProcess::errorOccurred(QProcess::ProcessError error )**

        This signal is emitted when an error occurs with the process. The
        specified **error** describes the type of error that occurred.

        This function was introduced in Qt 5.6.
        """
        ...

    @property
    def finished(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qprocess.html#finished

        **[signal] void QProcess::finished(int exitCode , QProcess::ExitStatus
        exitStatus = NormalExit)**

        This signal is emitted when the process finishes. **exitCode** is the
        exit code of the process (only valid for normal exits), and
        **exitStatus** is the exit status. After the process has finished, the
        buffers in **QProcess**  are still intact. You can still read any data
        that the process may have written before it finished.

        **See also** **exitStatus** ().
        """
        ...

    @property
    def readyReadStandardError(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qprocess.html#readyReadStandardError

        **[private signal] void QProcess::readyReadStandardError()**

        This signal is emitted when the process has made new data available
        through its standard error channel (`stderr`). It is emitted regardless
        of the current **read channel** .

        **Note:** This is a private signal. It can be used in signal connections
        but cannot be emitted by the user.

        **See also** **readAllStandardError** () and **readChannel** ().
        """
        ...

    @property
    def readyReadStandardOutput(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qprocess.html#readyReadStandardOutput

        **[private signal] void QProcess::readyReadStandardOutput()**

        This signal is emitted when the process has made new data available
        through its standard output channel (`stdout`). It is emitted regardless
        of the current **read channel** .

        **Note:** This is a private signal. It can be used in signal connections
        but cannot be emitted by the user.

        **See also** **readAllStandardOutput** () and **readChannel** ().
        """
        ...

    @property
    def started(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qprocess.html#started

        **[private signal] void QProcess::started()**

        This signal is emitted by **QProcess**  when the process has started,
        and **state** () returns **Running** .

        **Note:** This is a private signal. It can be used in signal connections
        but cannot be emitted by the user.
        """
        ...

    @property
    def stateChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qprocess.html#stateChanged

        **[private signal] void QProcess::stateChanged(QProcess::ProcessState
        newState )**

        This signal is emitted whenever the state of **QProcess**  changes. The
        **newState** argument is the state **QProcess**  changed to.

        **Note:** This is a private signal. It can be used in signal connections
        but cannot be emitted by the user.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtCore import *


class QSize(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qsize.html

    **Detailed Description**

    A size is specified by a **width** () and a **height** (). It can be set in
    the constructor and changed using the **setWidth** (), **setHeight** (), or
    **scale** () functions, or using arithmetic operators. A size can also be
    manipulated directly by retrieving references to the width and height using
    the **rwidth** () and **rheight** () functions. Finally, the width and
    height can be swapped using the **transpose** () function.

    The **isValid** () function determines if a size is valid (a valid size has
    both width and height greater than or equal to zero). The **isEmpty** ()
    function returns `true` if either of the width and height is less than, or
    equal to, zero, while the **isNull** () function returns `true` only if both
    the width and the height is zero.

    Use the **expandedTo** () function to retrieve a size which holds the
    maximum height and width of **this** size and a given size. Similarly, the
    **boundedTo** () function returns a size which holds the minimum height and
    width of **this** size and a given size.

    QSize objects can be streamed as well as compared.

    **See also** **QSizeF** , **QPoint** , and **QRect** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qsize.html#QSize

        **QSize::QSize()**

        Constructs a size with an invalid width and height (i.e., **isValid** ()
        returns `false`).

        **See also** **isValid** ().
        """
        ...

    @typing.overload
    def __init__(self, w: int, h: int) -> None:
        """
        https://doc.qt.io/qt-6/qsize.html#QSize-1

        **QSize::QSize(int width , int height )**

        Constructs a size with the given **width** and **height**.

        **See also** **setWidth** () and **setHeight** ().
        """
        ...

    @typing.overload
    def __init__(self, a0: "QSize") -> None:
        """
        https://doc.qt.io/qt-6/qsize.html#QSize

        **QSize::QSize()**

        Constructs a size with an invalid width and height (i.e., **isValid** ()
        returns `false`).

        **See also** **isValid** ().
        """
        ...

    def shrunkBy(self, m: QMargins) -> "QSize":
        """
        https://doc.qt.io/qt-6/qsize.html#shrunkBy

        **[since 5.14] QSize QSize::shrunkBy(QMargins margins ) const**

        Returns the size that results from shrinking this size by **margins**.

        This function was introduced in Qt 5.14.

        **See also** **grownBy** ().
        """
        ...

    def grownBy(self, m: QMargins) -> "QSize":
        """
        https://doc.qt.io/qt-6/qsize.html#grownBy

        **[since 5.14] QSize QSize::grownBy(QMargins margins ) const**

        Returns the size that results from growing this size by **margins**.

        This function was introduced in Qt 5.14.

        **See also** **shrunkBy** ().
        """
        ...

    def transposed(self) -> "QSize":
        """
        https://doc.qt.io/qt-6/qsize.html#transposed

        **[since 5.0] QSize QSize::transposed() const**

        Returns a **QSize**  with width and height swapped.

        This function was introduced in Qt 5.0.

        **See also** **transpose** ().
        """
        ...

    @typing.overload
    def scaled(self, s: "QSize", mode: Qt.AspectRatioMode) -> "QSize":
        """
        https://doc.qt.io/qt-6/qsize.html#scaled

        **[since 5.0] QSize QSize::scaled(int width , int height ,
        Qt::AspectRatioMode mode ) const**

        Return a size scaled to a rectangle with the given **width** and
        **height** , according to the specified **mode**.

        This function was introduced in Qt 5.0.

        **See also** **scale** ().
        """
        ...

    @typing.overload
    def scaled(self, w: int, h: int, mode: Qt.AspectRatioMode) -> "QSize":
        """
        https://doc.qt.io/qt-6/qsize.html#scaled-1

        **[since 5.0] QSize QSize::scaled(const QSize & s , Qt::AspectRatioMode
        mode ) const**

        This is an overloaded function.

        Return a size scaled to a rectangle with the given size **s** ,
        according to the specified **mode**.

        This function was introduced in Qt 5.0.
        """
        ...

    def boundedTo(self, otherSize: "QSize") -> "QSize":
        """
        https://doc.qt.io/qt-6/qsize.html#boundedTo

        **QSize QSize::boundedTo(const QSize & otherSize ) const**

        Returns a size holding the minimum width and height of this size and the
        given **otherSize**.

        **See also** **expandedTo** () and **scale** ().
        """
        ...

    def expandedTo(self, otherSize: "QSize") -> "QSize":
        """
        https://doc.qt.io/qt-6/qsize.html#expandedTo

        **QSize QSize::expandedTo(const QSize & otherSize ) const**

        Returns a size holding the maximum width and height of this size and the
        given **otherSize**.

        **See also** **boundedTo** () and **scale** ().
        """
        ...

    def setHeight(self, h: int) -> None:
        """
        https://doc.qt.io/qt-6/qsize.html#setHeight

        **void QSize::setHeight(int height )**

        Sets the height to the given **height**.

        **See also** **rheight** (), **height** (), and **setWidth** ().
        """
        ...

    def setWidth(self, w: int) -> None:
        """
        https://doc.qt.io/qt-6/qsize.html#setWidth

        **void QSize::setWidth(int width )**

        Sets the width to the given **width**.

        **See also** **rwidth** (), **width** (), and **setHeight** ().
        """
        ...

    def height(self) -> int:
        """
        https://doc.qt.io/qt-6/qsize.html#height

        **int QSize::height() const**

        Returns the height.

        **See also** **width** () and **setHeight** ().
        """
        ...

    def width(self) -> int:
        """
        https://doc.qt.io/qt-6/qsize.html#width

        **int QSize::width() const**

        Returns the width.

        **See also** **height** () and **setWidth** ().
        """
        ...

    def __hash__(self) -> int:
        ...

    def __bool__(self) -> int:
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsize.html#isValid

        **bool QSize::isValid() const**

        Returns `true` if both the width and height is equal to or greater than
        0; otherwise returns `false`.

        **See also** **isNull** () and **isEmpty** ().
        """
        ...

    def isEmpty(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsize.html#isEmpty

        **bool QSize::isEmpty() const**

        Returns `true` if either of the width and height is less than or equal
        to 0; otherwise returns `false`.

        **See also** **isNull** () and **isValid** ().
        """
        ...

    def isNull(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsize.html#isNull

        **bool QSize::isNull() const**

        Returns `true` if both the width and height is 0; otherwise returns
        false.

        **See also** **isValid** () and **isEmpty** ().
        """
        ...

    def __repr__(self) -> str:
        ...

    @typing.overload
    def scale(self, s: "QSize", mode: Qt.AspectRatioMode) -> None:
        """
        https://doc.qt.io/qt-6/qsize.html#scale

        **void QSize::scale(int width , int height , Qt::AspectRatioMode mode
        )**

        Scales the size to a rectangle with the given **width** and **height** ,
        according to the specified **mode** :

        * If **mode** is **Qt::IgnoreAspectRatio** , the size is set to (
        **width** , **height** ).
          * If **mode** is **Qt::KeepAspectRatio** ,
        the current size is scaled to a rectangle as large as possible inside (
        **width** , **height** ), preserving the aspect ratio.
          * If **mode**
        is **Qt::KeepAspectRatioByExpanding** , the current size is scaled to a
        rectangle as small as possible outside ( **width** , **height** ),
        preserving the aspect ratio.

        Example:

        **QSize**  t1(10, 12);
            t1.scale(60, 60, Qt::IgnoreAspectRatio);
        // t1 is (60, 60)

            **QSize**  t2(10, 12);
            t2.scale(60, 60,
        Qt::KeepAspectRatio);
            // t2 is (50, 60)

            **QSize**  t3(10,
        12);
            t3.scale(60, 60, Qt::KeepAspectRatioByExpanding);
            // t3 is
        (60, 72)

        **See also** **setWidth** (), **setHeight** (), and **scaled** ().
        """
        ...

    @typing.overload
    def scale(self, w: int, h: int, mode: Qt.AspectRatioMode) -> None:
        """
        https://doc.qt.io/qt-6/qsize.html#scale-1

        **void QSize::scale(const QSize & size , Qt::AspectRatioMode mode )**

        This is an overloaded function.

        Scales the size to a rectangle with the given **size** , according to
        the specified **mode**.
        """
        ...

    def transpose(self) -> None:
        """
        https://doc.qt.io/qt-6/qsize.html#transpose

        **void QSize::transpose()**

        Swaps the width and height values.

        **See also** **setWidth** (), **setHeight** (), and **transposed** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from typing import Union, overload
from PyQt6.sip import *


class voidptr:
    def __init__(
        addr: Union[int, Buffer], size: int = -1, writeable: bool = True
    ) -> None:
        ...

    def __int__(self) -> int:
        ...

    @overload
    def __getitem__(self, i: int) -> bytes:
        ...

    @overload
    def __getitem__(self, s: slice) -> voidptr:
        ...

    def __hex__(self) -> str:
        ...

    def __len__(self) -> int:
        ...

    def __setitem__(self, i: Union[int, slice], v: Buffer) -> None:
        ...

    def asarray(self, size: int = -1) -> array:
        ...

    def asstring(self, size: int = -1) -> bytes:
        ...

    def getsize(self) -> int:
        ...

    def getwriteable(self) -> bool:
        ...

    def setsize(self, size: int) -> None:
        ...

    def setwriteable(self, bool) -> None:
        ...
